/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as j, createVNode as o, h as f } from "vue";
import { getModelFields as g, toSchedulerGroups as z, findMaster as p, setField as l, getField as r, getToday as M } from "./utils/main.mjs";
import { isRtl as L, validatePackage as B, shouldShowValidationUI as _, templateRendering as d, getListeners as v, getTemplate as D, WatermarkOverlay as U, clone as c } from "@progress/kendo-vue-common";
import { SchedulerHeader as G } from "./components/header/SchedulerHeader.mjs";
import { provideIntlService as V } from "@progress/kendo-vue-intl";
import { SchedulerNavigation as K } from "./components/header/navigation/SchedulerNavigation.mjs";
import { addMonths as C, addDays as b } from "@progress/kendo-date-math";
import { SchedulerFooter as q } from "./components/footer/SchedulerFooter.mjs";
import { ToolbarSpacer as J } from "@progress/kendo-vue-buttons";
import { NavigationDatePicker as Q } from "./components/header/navigation/NavigationDatePicker.mjs";
import { ViewSelectorList as X } from "./components/header/view-selector/ViewSelectorList.mjs";
import { BusinessHours as Y } from "./components/footer/bussiness-hours/BusinessHours.mjs";
import { packageMetadata as S } from "./package-metadata.mjs";
import { AgendaView as Z } from "./views/agenda/AgendaView.mjs";
import { TimelineView as ee } from "./views/time/TimelineView.mjs";
import { DayView as m } from "./views/day/DayView.mjs";
import { WeekView as te } from "./views/week/WeekView.mjs";
import { WorkWeekView as ie } from "./views/week/WorkWeekView.mjs";
import { MonthView as se } from "./views/month/MonthView.mjs";
import { DATA_ACTION as w } from "./constants/main.mjs";
import { useEditable as re } from "./hooks/useEditable.mjs";
const I = "{0:D}", $ = "{0:d}", $e = /* @__PURE__ */ j({
  name: "KendoScheduler",
  emits: ["datechange", "viewchange", "datachange", "itemclick", "itemdoubleclick", "slotclick", "slotdoubleclick", "taskclick", "taskdoubleclick"],
  props: {
    dataItems: {
      type: Array,
      default: function() {
        return [];
      }
    },
    views: {
      type: Array,
      default: function() {
        return [];
      }
    },
    view: String,
    defaultView: String,
    date: Date,
    rtl: Boolean,
    height: {
      type: [Number, String],
      default: 600
    },
    timezone: String,
    group: Object,
    resources: [Object, Array],
    modelFields: Object,
    tabIndex: {
      type: Number,
      default: -1
    },
    editable: {
      type: [Boolean, Object],
      default: !1
    },
    defaultDate: {
      type: Date,
      default: function() {
        return /* @__PURE__ */ new Date();
      }
    },
    validator: {
      type: Function,
      default: () => ({})
    },
    modifyInitialFormValues: {
      type: Function,
      default: (e) => e
    },
    header: [String, Function, Object],
    footer: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    task: [String, Function, Object],
    form: [String, Function, Object],
    resizeHint: [String, Function, Object],
    dialogProps: Object,
    formProps: Object,
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object]
  },
  computed: {
    isRtl() {
      return this.$props.rtl !== void 0 ? this.$props.rtl : this.currentRtl;
    },
    wrapperClassName() {
      return {
        "k-rtl": this.isRtl,
        "k-scheduler": !0
      };
    },
    fields() {
      return g(this.$props.modelFields).fields;
    }
  },
  mounted() {
    this.currentRtl = L(this.$el);
  },
  provide() {
    return {
      ks: this.ks,
      setActiveViewName: this.handleActiveViewNameChange,
      setActiveDate: this.handleDateChange,
      itemDoubleClick: this.handleItemDoubleClick,
      itemClick: this.handleItemClick,
      slotDoubleClick: this.handleSlotDoubleClick,
      slotClick: this.handleSlotClick,
      taskDoubleClick: this.handleTaskDoubleClick,
      taskClick: this.handleTaskClick,
      ksValidator: this.validator,
      ksModifyInitialFormValues: this.modifyInitialFormValues
    };
  },
  inject: {
    kendoLocalizationService: {
      default: null
    },
    kendoIntlService: {
      default: null
    }
  },
  data() {
    const e = V(this), i = this.$props.date || this.$props.defaultDate, s = this.$props.view || this.$props.defaultView || this.views[0] && this.views[0].name || "day", t = this.views.find((u) => u.name === s) || this.views[0] || o(m, null, null), a = this.getViewPropValue(t, "selectedDateFormat", s) || I, n = this.getViewPropValue(t, "selectedShortDateFormat", s) || $, h = this.getViewComponentByName(s).props.dateRange.default()({
      intl: e,
      date: i,
      timezone: this.$props.timezone,
      numberOfDays: this.getViewPropValue(t, "numberOfDays", s),
      workWeekStart: this.getViewPropValue(t, "workWeekStart", s) || e.firstDay(),
      workWeekEnd: this.getViewPropValue(t, "workWeekEnd", s) || (e.firstDay() + this.getViewPropValue(t, "numberOfDays", s)) % 6
    });
    return {
      ks: {
        activeViewName: s,
        currentDate: i,
        showWorkHours: t.showWorkHours !== void 0 ? t.showWorkHours : !0,
        timezone: this.$props.timezone,
        props: {
          ...this.$props
        },
        views: this.views,
        view: t,
        fields: g(this.$props.modelFields).fields,
        groups: z(this.$props.group, this.$props.resources),
        dateRange: h,
        orientation: this.$props.group && this.$props.group.orientation ? this.$props.group.orientation : "horizontal",
        dateFormat: a,
        shortDateFormat: n,
        scheduler: this,
        dataItems: this.dataItems
      }
    };
  },
  watch: {
    isRtl(e) {
      this.ks.isRtl = e;
    },
    view(e) {
      this.updatePassedState(e);
    },
    date(e) {
      this.ks.currentDate = e, this.updatePassedState();
    },
    timezone(e) {
      this.ks.timezone = e, this.updatePassedState();
    },
    dataItems(e) {
      this.ks.dataItems = e;
    }
  },
  render() {
    B(S), this.showLicenseWatermark = _(S);
    const e = this.views.find((T) => T.name === this.ks.activeViewName) || this.views[0] || o(m, null, null), i = this.getViewPropValue(this.ks.view, "slotDuration", this.ks.activeViewName), s = d.call(this, e.header || this.$props.header, v.call(this)), t = d.call(this, e.footer || this.$props.footer, v.call(this)), a = d.call(this, e.slot || this.$props.slotRender, {}), n = d.call(this, e.viewSlot || this.$props.viewSlot, {}), h = d.call(this, e.item || this.$props.item, {}), u = d.call(this, e.viewItem || this.$props.viewItem, {}), k = d.call(this, e.task || this.$props.task, {}), y = d.call(this, e.dateHeaderCell || this.$props.dateHeaderCell, {}), R = d.call(this, e.timeHeaderCell || this.$props.timeHeaderCell, {}), P = d.call(this, e.resizeHint || this.$props.resizeHint, {});
    this.ks.form = d.call(this, e.form || this.$props.form, {}), this.ks.dialogProps = e.dialogProps || this.$props.dialogProps, this.ks.formProps = e.formProps || this.$props.formProps;
    const F = re(e.editable !== void 0 ? e.editable : this.$props.editable), x = this.getViewComponentByName(this.ks.activeViewName || e.name), N = {
      ...this.$props,
      ...this.ks.view,
      showWorkHours: this.ks.showWorkHours,
      dataItems: void 0,
      views: void 0,
      defaultDate: void 0,
      dateRange: this.ks.dateRange,
      slotRender: a,
      viewSlot: n,
      item: h,
      viewItem: u,
      task: k,
      dateHeaderCell: y,
      timeHeaderCell: R,
      resizeHint: P,
      editable: F
    }, E = o(G, null, {
      default: () => [o(K, {
        isRtl: this.isRtl,
        onPrevclick: this.handlePrevClick,
        onNextclick: this.handleNextClick,
        onTodayclick: this.handleTodayClick
      }, null), o(Q, {
        value: this.ks.currentDate,
        onChange: this.handleDatePickerChange
      }, null), o(J, null, null), o(X, null, null)]
    }), O = D.call(this, {
      h: f,
      template: s,
      defaultRendering: E,
      additionalProps: {
        currentDate: this.ks.currentDate
      },
      additionalListeners: {
        prevclick: this.handlePrevClick,
        nextclick: this.handleNextClick,
        todayclick: this.handleTodayClick,
        datepickerchange: this.handleDatePickerChange
      }
    }), H = o(q, null, {
      default: () => [o(Y, {
        slotDuration: i,
        onClick: this.handleShowWorkHoursClick
      }, null)]
    }), W = D.call(this, {
      h: f,
      template: t,
      defaultRendering: H,
      additionalProps: {
        slotDuration: i
      },
      additionalListeners: {
        showworkhoursclick: this.handleShowWorkHoursClick
      }
    }), A = this.showLicenseWatermark ? o(U, null, null) : null;
    return o("div", {
      id: this.$props.id,
      style: {
        height: this.$props.height + "px"
      },
      class: this.wrapperClassName,
      tabindex: this.$props.tabIndex,
      dir: this.isRtl && "rtl",
      role: this.$props.role || "application",
      "aria-label": this.$props.ariaLabel,
      "aria-labelledby": this.$props.ariaLabelledby,
      onFocusin: this.handleFocus,
      onFocusout: this.handleBlur
    }, [O, f(x, {
      key: this.ks.view.name,
      onDataaction: this.handleDataAction,
      ...N
    }), W, A]);
  },
  methods: {
    getViewComponentByName(e) {
      switch (e.toLowerCase()) {
        case "week":
          return te;
        case "workweek":
          return ie;
        case "agenda":
          return Z;
        case "timeline":
          return ee;
        case "month":
          return se;
        default:
          return m;
      }
    },
    getViewPropValue(e, i, s) {
      const t = this.getViewComponentByName(s).props[i];
      return e[i] || (t ? t.default : void 0);
    },
    handleDataChange({
      created: e = [],
      updated: i = [],
      deleted: s = []
    }) {
      const t = {
        created: e,
        updated: i,
        deleted: s
      };
      this.$emit("datachange", t);
    },
    handleCreate(e) {
      const i = [e.dataItem];
      this.handleDataChange({
        created: i
      });
    },
    handleUpdate(e) {
      const i = [], s = [];
      if (e.series)
        if (Array.isArray(e.dataItem))
          e.dataItem.map((t) => {
            const a = c(p(e.dataItem, this.fields, this.dataItems)), n = c(t);
            l(n, this.fields.originalStart, r(a, this.fields.originalStart)), l(n, this.fields.recurrenceId, r(a, this.fields.recurrenceId)), l(n, this.fields.recurrenceExceptions, r(a, this.fields.recurrenceExceptions)), s.push(n);
          });
        else {
          const t = c(p(e.dataItem, this.fields, this.dataItems)), a = c(e.dataItem);
          l(a, this.fields.originalStart, r(t, this.fields.originalStart)), l(a, this.fields.recurrenceId, r(t, this.fields.recurrenceId)), l(a, this.fields.recurrenceExceptions, r(t, this.fields.recurrenceExceptions)), s.push(a);
        }
      else if (Array.isArray(e.dataItem))
        e.dataItem.map((t) => {
          const a = r(t, this.fields.recurrenceRule) !== null && r(t, this.fields.recurrenceRule) !== void 0;
          if (r(t, this.fields.recurrenceId) !== null && r(t, this.fields.recurrenceId) !== void 0 && a) {
            const h = c(p(t, this.fields, this.dataItems)), u = r(t, this.fields.originalStart), k = r(h, this.fields.recurrenceExceptions) || [];
            l(h, this.fields.recurrenceExceptions, [...k, u]), l(t, this.fields.recurrenceRule, null), s.push(h), i.push(t);
          } else
            s.push(t);
        });
      else {
        const t = r(e.dataItem, this.fields.recurrenceRule) !== null && r(e.dataItem, this.fields.recurrenceRule) !== void 0;
        if (r(e.dataItem, this.fields.recurrenceId) !== null && r(e.dataItem, this.fields.recurrenceId) !== void 0 && t) {
          const n = c(p(e.dataItem, this.fields, this.dataItems)), h = r(e.dataItem, this.fields.originalStart), u = r(n, this.fields.recurrenceExceptions) || [];
          l(n, this.fields.recurrenceExceptions, [...u, h]), l(e.dataItem, this.fields.recurrenceRule, null), s.push(n), i.push(e.dataItem);
        } else
          s.push(e.dataItem);
      }
      this.handleDataChange({
        updated: s,
        created: i
      });
    },
    handleRemove(e) {
      const i = [], s = [];
      if (e.series) {
        const t = c(p(e.dataItem, this.fields, this.dataItems)), a = c(e.dataItem);
        l(a, this.fields.originalStart, r(t, this.fields.originalStart)), l(a, this.fields.recurrenceId, r(t, this.fields.recurrenceId)), l(a, this.fields.recurrenceRule, r(t, this.fields.recurrenceRule)), l(a, this.fields.recurrenceExceptions, r(t, this.fields.recurrenceExceptions)), s.push(a);
      } else if (!(r(e.dataItem, this.fields.recurrenceRule) !== null && r(e.dataItem, this.fields.recurrenceRule) !== void 0))
        s.push(e.dataItem);
      else {
        const a = c(p(e.dataItem, this.fields, this.dataItems)), n = r(e.dataItem, this.fields.originalStart), h = r(a, this.fields.recurrenceExceptions) || [];
        l(a, this.fields.recurrenceExceptions, [...h, n]), l(e.dataItem, this.fields.recurrenceRule, null), i.push(a);
      }
      this.handleDataChange({
        updated: i,
        deleted: s
      });
    },
    handleDataAction(e) {
      switch (e.type) {
        case w.create:
          this.handleCreate(e);
          break;
        case w.update:
          this.handleUpdate(e);
          break;
        case w.remove:
          this.handleRemove(e);
          break;
      }
    },
    handleActiveViewNameChange(e, i) {
      this.updatePassedState(e), this.$emit("viewchange", {
        viewName: e,
        ...i,
        target: this.ks.scheduler.$el
      });
    },
    handleDateChange(e, i) {
      this.setDate(e, {
        ...i,
        target: this.ks.scheduler.$el
      });
    },
    handleDatePickerChange(e) {
      e.value && this.setDate(e.value, {
        ...e,
        target: this.ks.scheduler.$el,
        nativeEvent: e.event
      });
    },
    handleNextClick(e) {
      e.preventDefault();
      const i = this.getViewPropValue(this.ks.view, "step", this.ks.activeViewName) || this.getViewPropValue(this.ks.view, "numberOfDays", this.ks.activeViewName) || 1, t = i > 27 ? C(this.ks.currentDate, Math.round(i / 27)) : b(this.ks.currentDate, i);
      this.setDate(t, e);
    },
    handlePrevClick(e) {
      e.preventDefault();
      const i = this.getViewPropValue(this.ks.view, "step", this.ks.activeViewName) || this.getViewPropValue(this.ks.view, "numberOfDays", this.ks.activeViewName) || 1, t = i > 27 ? C(this.ks.currentDate, -Math.round(i / 27)) : b(this.ks.currentDate, -i);
      this.setDate(t, e);
    },
    handleTodayClick(e) {
      e.preventDefault();
      const i = M();
      this.setDate(i, e);
    },
    handleShowWorkHoursClick() {
      this.ks.showWorkHours = !this.ks.showWorkHours;
    },
    handleFocus() {
      this.$el && (this.$el.style.boxShadow = "0 0.5px 0.5px 0.5px rgba(0, 0, 0, .12)");
    },
    handleBlur() {
      this.$el && (this.$el.style.boxShadow = "");
    },
    handleItemClick(e) {
      this.$emit("itemclick", e);
    },
    handleItemDoubleClick(e) {
      this.$emit("itemdoubleclick", e);
    },
    handleSlotClick(e) {
      this.$emit("slotclick", e);
    },
    handleSlotDoubleClick(e) {
      this.$emit("slotdoubleclick", e);
    },
    handleTaskClick(e) {
      this.$emit("taskclick", e);
    },
    handleTaskDoubleClick(e) {
      this.$emit("taskdoubleclick", e);
    },
    setDate(e, i) {
      this.ks.currentDate = e, this.updatePassedState(), this.$emit("datechange", {
        date: e,
        event: i
      });
    },
    updatePassedState(e) {
      const i = V(this), s = e || this.ks.activeViewName;
      this.ks.activeViewName = s, this.ks.view = this.views.find((t) => t.name === s) || this.views[0] || o(m, null, null), this.ks.dateFormat = this.getViewPropValue(this.ks.view, "selectedDateFormat", s) || I, this.ks.shortDateFormat = this.getViewPropValue(this.ks.view, "selectedShortDateFormat", s) || $, this.ks.dateRange = this.getViewComponentByName(s).props.dateRange.default()({
        intl: i,
        date: this.ks.currentDate,
        timezone: this.$props.timezone,
        numberOfDays: this.getViewPropValue(this.ks.view, "numberOfDays", this.ks.activeViewName),
        workWeekStart: this.getViewPropValue(this.ks.view, "workWeekStart", this.ks.activeViewName) || i.firstDay(),
        workWeekEnd: this.getViewPropValue(this.ks.view, "workWeekEnd", this.ks.activeViewName) || (i.firstDay() + this.getViewPropValue(this.ks.view, "numberOfDays", this.ks.activeViewName)) % 6
      });
    }
  }
});
export {
  $e as Scheduler
};
