/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as d, createVNode as c } from "vue";
import { dispatchSelectedItems as i, ITEMS_SELECT_ACTION as r } from "../hooks/use-items-selection.mjs";
import { dispatchSelectedSlots as l, SLOTS_SELECT_ACTION as a } from "../hooks/use-slots-selection.mjs";
import { getDefaultSlots as h } from "@progress/kendo-vue-common";
import { COLLECTION_ACTION as s } from "../utils/main.mjs";
import { useCellSync as o } from "../hooks/useCellSync.mjs";
import { dispatchFocusedItems as p } from "../hooks/use-items-focus.mjs";
import { dispatchFocusedSlots as m } from "../hooks/use-slots-focus.mjs";
const C = /* @__PURE__ */ d({
  name: "KendoBaseView",
  props: {
    viewProps: Object,
    baseSlots: Array,
    ranges: Array,
    id: String,
    isAgendaView: {
      type: Boolean,
      default: !1
    }
  },
  provide() {
    return {
      bv: this.bv,
      setItems: this.dispatchItems,
      setSlots: this.dispatchSlots,
      dispatchSelectedSlots: this.handleSchedulerSlotsSelectAction,
      dispatchSelectedItems: this.handleSchedulerItemsSelectAction,
      dispatchFocusedItems: this.setFocusedItems,
      dispatchFocusedSlots: this.setFocusedSlots
      //    setActiveViewName: this.handleActiveViewNameChange
    };
  },
  data() {
    return {
      bv: {
        viewProps: this.viewProps,
        ranges: this.ranges,
        items: [],
        slots: [],
        focusedItems: [],
        focusedSlots: [],
        selectedItems: [],
        selectedSlots: []
      }
    };
  },
  mounted() {
    this.syncCells();
  },
  updated() {
    this.syncCells();
  },
  render() {
    const e = h(this);
    return c("div", {
      class: "k-scheduler-layout k-scheduler-layout-flex",
      role: this.$props.isAgendaView ? "grid" : "presentation"
    }, [e]);
  },
  methods: {
    syncCells() {
      o({
        element: this.$el,
        selector: ".k-group-cell",
        attribute: "data-depth-index",
        explicitDepth: !0
      }), o({
        element: this.$el,
        selector: ".k-side-cell",
        attribute: "data-depth-index",
        explicitDepth: !1
      });
    },
    handleSchedulerItemsSelectAction(e, t) {
      l.call(this, {
        type: a.reset
      }), i.call(this, e, t);
    },
    handleSchedulerSlotsSelectAction(e, t) {
      i.call(this, {
        type: r.reset
      }, t), l.call(this, e);
    },
    setFocusedItems(e, t) {
      p.call(this, e, t);
    },
    setFocusedSlots(e, t) {
      m.call(this, e, t);
    },
    dispatchItems(e) {
      let t;
      switch (e.type) {
        case s.add:
          this.bv.items.push(e.item);
          break;
        case s.remove:
          t = this.bv.items.indexOf(e.item), this.bv.items.splice(t, 1);
          break;
      }
    },
    dispatchSlots(e) {
      let t;
      switch (e.type) {
        case s.add:
          this.bv.slots.push(e.item);
          break;
        case s.remove:
          t = this.bv.slots.indexOf(e.item), this.bv.slots.splice(t, 1);
          break;
      }
    }
  }
});
export {
  C as BaseView
};
