/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as S, inject as M, createVNode as r, h as n } from "vue";
import { SchedulerActionButtons as V } from "./SchedulerActionButtons.mjs";
import { Form as v } from "@progress/kendo-vue-form";
import { Dialog as C } from "@progress/kendo-vue-dialogs";
import { provideLocalizationService as I } from "@progress/kendo-vue-intl";
import { SchedulerFormEditor as L } from "../editors/SchedulerFormEditor.mjs";
import { editorValidationRequired as l, messages as a, editorValidationEnd as c, editorSave as h, editorCancel as u, editorTitle as m, editorValidationStart as g } from "../messages/main.mjs";
import { guid as T, getTemplate as b, canUseDOM as q } from "@progress/kendo-vue-common";
const $ = /* @__PURE__ */ S({
  name: "KendoSchedulerForm",
  emits: {
    cancel: null,
    close: null,
    submit: null
  },
  props: {
    dataItem: Object
  },
  inject: {
    ks: {
      default: null
    },
    kendoLocalizationService: {
      default: null
    },
    ksValidator: {
      default: null
    },
    ksModifyInitialFormValues: {
      default: null
    }
  },
  created() {
    this.dialogId = T();
  },
  data() {
    return {
      media: "desktop"
    };
  },
  mounted() {
    this.calculateMedia(), setTimeout(() => {
      const t = document.getElementById(this.dialogId);
      t && t.focus();
    }, 10);
  },
  setup() {
    return {
      kendoLocalizationService: M("kendoLocalizationService", {})
    };
  },
  render() {
    const t = this, e = I(this);
    this.requiredValidationMessage = e.toLanguageString(l, a[l]), this.endValidationMessage = e.toLanguageString(c, a[c]);
    const i = e.toLanguageString(h, a[h]), o = e.toLanguageString(u, a[u]), s = e.toLanguageString(m, a[m]);
    this.startValidationMessage = e.toLanguageString(g, a[g]);
    const d = r(L, null, {
      default: () => [r(V, {
        editSaveMessage: i,
        editCancelMessage: o,
        onCancel: this.handleCancel
      }, null)]
    }), f = b.call(this, {
      h: n,
      template: this.ks.form,
      defaultRendering: d,
      additionalProps: {
        dataItem: this.dataItem,
        editSaveMessage: i,
        editCancelMessage: o
      },
      additionalListeners: {
        cancel: this.handleCancel
      }
    }), p = {
      title: s,
      appendTo: "body",
      minWidth: this.media === "desktop" ? 400 : "85%",
      wrapperId: this.dialogId,
      ...this.ks.dialogProps
    }, k = {
      initialValues: t.ksModifyInitialFormValues(t.$props.dataItem),
      validator: t.formValidator,
      ...this.ks.formProps
    };
    return n(C, {
      onClose: this.handleClose,
      class: "k-scheduler-edit-dialog",
      ...p
    }, function() {
      return [n(v, {
        onSubmit: t.handleSubmit,
        ...k
      }, function() {
        return [f];
      })];
    });
  },
  methods: {
    calculateMedia() {
      q && window.matchMedia && (this.media = window.matchMedia("(min-width: 600px)").matches ? "desktop" : "mobile");
    },
    handleCancel(t) {
      this.$emit("cancel", {
        value: null,
        event: t,
        target: this.form
      });
    },
    handleClose({
      event: t
    }) {
      this.$emit("close", {
        value: null,
        event: t,
        target: this.form
      });
    },
    handleSubmit(t, e) {
      this.$emit("submit", {
        value: t,
        event: e,
        target: this.form
      });
    },
    startAfterEndValidator(t, e) {
      return t && e(this.ks.fields.end) && t.getTime() > e(this.ks.fields.end).getTime() ? this.startValidationMessage : void 0;
    },
    endAfterStartValidator(t, e) {
      return t && e(this.ks.fields.start) && t.getTime() < e(this.ks.fields.start).getTime() ? this.endValidationMessage : void 0;
    },
    requiredValidator(t) {
      return t ? void 0 : this.requiredValidationMessage;
    },
    formValidator(t, e) {
      const i = {};
      i[this.ks.fields.start] = [this.requiredValidator(e(this.ks.fields.start)), this.startAfterEndValidator(e(this.ks.fields.start), e)].filter(Boolean).reduce((s, d) => s || d, ""), i[this.ks.fields.end] = [this.requiredValidator(e(this.ks.fields.start)), this.endAfterStartValidator(e(this.ks.fields.start), e)].filter(Boolean).reduce((s, d) => s || d, "");
      const o = this.ksValidator(e);
      return {
        ...i,
        ...o
      };
    }
  }
});
export {
  $ as SchedulerForm
};
