/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as c, createVNode as o } from "vue";
import { Calendar as l } from "@progress/kendo-vue-dateinputs";
import { ZonedDate as r, getDate as m, MS_PER_DAY as f } from "@progress/kendo-date-math";
import { Popup as p } from "@progress/kendo-vue-popup";
import { provideIntlService as k } from "@progress/kendo-vue-intl";
import { Button as v } from "@progress/kendo-vue-buttons";
import { toUTCDateTime as w } from "../../../utils/main.mjs";
import { guid as d, canUseDOM as i, Keys as b } from "@progress/kendo-vue-common";
import { calendarIcon as g } from "@progress/kendo-svg-icons";
const F = /* @__PURE__ */ c({
  name: "KendoNavigationDatePicker",
  props: {
    value: [Date, Object],
    onChange: Function
  },
  inject: {
    kendoIntlService: {
      default: null
    },
    ks: {
      default: null
    }
  },
  created() {
    this.buttonId = d(), this._popupId = "popup" + d();
  },
  data() {
    return {
      hasMounted: !1,
      show: !1,
      focused: !1,
      media: "desktop"
    };
  },
  mounted() {
    this.buttonRef = this.$refs.button, this.calculateMedia(), i && window.ResizeObserver && (this.observer = new window.ResizeObserver(this.calculateMedia), this.ks.scheduler && this.ks.scheduler.$el && this.observer.observe(this.ks.scheduler.$el)), this.hasMounted = !0;
  },
  unmounted() {
    this.observer && this.observer.disconnect();
  },
  updated() {
    this.show && this.focused && this.$refs.calendar && this.$refs.calendar.focus();
  },
  render() {
    const t = r.fromLocalDate(this.$props.value || this.ks.currentDate, this.ks.timezone), e = m(t), n = this.show, s = this.ks.dateRange.end.getTime() - this.ks.dateRange.start.getTime() > f * 27, a = k(this), h = a.format(this.ks.dateFormat, s ? this.ks.currentDate : this.ks.dateRange.zonedStart, s ? this.ks.currentDate : this.ks.dateRange.zonedEnd.addDays(-1)), u = a.format(this.ks.shortDateFormat, s ? this.ks.currentDate : this.ks.dateRange.zonedStart, s ? this.ks.currentDate : this.ks.dateRange.zonedEnd.addDays(-1));
    return o(v, {
      ref: "button",
      id: this.buttonId,
      onFocus: this.onFocus,
      onBlur: this.onBlur,
      fillMode: "flat",
      class: "k-nav-current",
      "aria-live": "polite",
      tabIndex: -1,
      icon: "calendar",
      svgIcon: g,
      onClick: this.handleClick
    }, {
      default: () => [this.media === "desktop" ? h : u, o(p, {
        id: this._popupId,
        anchor: this.buttonId,
        show: n
      }, {
        default: () => [this.hasMounted && o(l, {
          ref: "calendar",
          onBlur: this.onCalendarBlur,
          onChange: this.handleChange,
          onKeydown: this.calendarKeydown,
          value: e
        }, null)]
      })]
    });
  },
  methods: {
    handleChange(t) {
      const e = r.fromUTCDate(w(t.value), this.ks.timezone);
      this.$emit("change", {
        ...t,
        value: e
      }), this.hideAndFocusButton();
    },
    handleClick() {
      this.show = !this.show;
    },
    onFocus() {
      clearTimeout(this._blurTimeout), this.focused = !0;
    },
    onBlur() {
      this.focused = !1;
    },
    onCalendarBlur() {
      clearTimeout(this._blurTimeout), this.createBlurTimeout();
    },
    createBlurTimeout() {
      const t = this;
      this._blurTimeout = setTimeout(() => {
        this.focused = !1;
        const e = document.activeElement && document.activeElement.closest(`#${t._popupId}`);
        i && document.activeElement !== t.$refs.button.$el && !e && (t.show = !1);
      }, 200);
    },
    calendarKeydown(t) {
      t.keyCode === b.esc && this.hideAndFocusButton();
    },
    hideAndFocusButton() {
      this.show = !1, this.$refs.button.focus();
    },
    calculateMedia() {
      i && window.matchMedia && (this.media = window.matchMedia("(min-width: 1024px)").matches ? "desktop" : "mobile");
    }
  }
});
export {
  F as NavigationDatePicker
};
