/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as he, createVNode as e, isVNode as me } from "vue";
import { timezoneNames as fe } from "@progress/kendo-date-math";
import { Label as l, Error as h } from "@progress/kendo-vue-labels";
import { provideLocalizationService as ke } from "@progress/kendo-vue-intl";
import { FormElement as pe, FieldWrapper as d, Field as t } from "@progress/kendo-vue-form";
import { TextBox as be, Checkbox as T, TextArea as ge } from "@progress/kendo-vue-inputs";
import { getDefaultSlots as Ee, templateRendering as i, getListeners as n } from "@progress/kendo-vue-common";
import { editorValidationRequired as S, messages as c, editorEventTitle as y, editorEventStart as v, editorEventTimeZone as L, editorEventStartTimeZone as C, editorEventEnd as j, editorEventSeparateTimeZones as O, editorEventEndTimeZone as Z, editorEventAllDay as x, editorEventDescription as D } from "../messages/main.mjs";
import { FilterableComboBox as w } from "./FilterableComboBox.mjs";
import { RecurrenceEditor as ze } from "../recurrence/RecurrenceEditor.mjs";
import { ResourceEditor as Fe } from "./ResourceEditor.mjs";
import { ZonedDateTime as I } from "./ZonedDateTime.mjs";
function u(o) {
  return typeof o == "function" || Object.prototype.toString.call(o) === "[object Object]" && !me(o);
}
const Ie = /* @__PURE__ */ he({
  name: "KendoSchedulerFormEditor",
  props: {
    as: [String, Function, Object],
    id: String,
    tabIndex: Number,
    titleLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    titleError: {
      type: [String, Function, Object],
      default: function() {
        return h;
      }
    },
    titleEditor: {
      type: [String, Function, Object],
      default: function() {
        return be;
      }
    },
    startLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    startError: {
      type: [String, Function, Object],
      default: function() {
        return h;
      }
    },
    startEditor: {
      type: [String, Function, Object],
      default: function() {
        return I;
      }
    },
    startTimezoneLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    startTimezoneError: {
      type: [String, Function, Object],
      default: function() {
        return h;
      }
    },
    startTimezoneEditor: {
      type: [String, Function, Object],
      default: function() {
        return w;
      }
    },
    startTimezoneCheckedLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    startTimezoneCheckedEditor: {
      type: [String, Function, Object],
      default: function() {
        return T;
      }
    },
    endLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    endError: {
      type: [String, Function, Object],
      default: function() {
        return h;
      }
    },
    endEditor: {
      type: [String, Function, Object],
      default: function() {
        return I;
      }
    },
    endTimezoneLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    endTimezoneError: {
      type: [String, Function, Object],
      default: function() {
        return h;
      }
    },
    endTimezoneEditor: {
      type: [String, Function, Object],
      default: function() {
        return w;
      }
    },
    endTimezoneCheckedLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    endTimezoneCheckedEditor: {
      type: [String, Function, Object],
      default: function() {
        return T;
      }
    },
    allDayLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    allDayEditor: {
      type: [String, Function, Object],
      default: function() {
        return T;
      }
    },
    recurrenceEditor: {
      type: [String, Function, Object],
      default: function() {
        return ze;
      }
    },
    descriptionLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    descriptionError: {
      type: [String, Function, Object],
      default: function() {
        return h;
      }
    },
    descriptionEditor: {
      type: [String, Function, Object],
      default: function() {
        return ge;
      }
    },
    resourceLabel: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    resourcesError: {
      type: [String, Function, Object],
      default: function() {
        return l;
      }
    },
    resourceEditor: {
      type: [String, Function, Object],
      default: function() {
        return Fe;
      }
    },
    errors: Object,
    valid: Boolean,
    touched: Boolean,
    visited: Boolean,
    modified: Boolean,
    submitted: Boolean,
    allowSubmit: Boolean,
    valueGetter: Function
  },
  created() {
    this.requiredValidationMessage = void 0;
  },
  inject: {
    ks: {
      default: null
    },
    kendoForm: {
      default: {}
    },
    kendoLocalizationService: {
      default: null
    }
  },
  data() {
    const o = this.kendoForm, s = this.ks;
    return {
      startZoneChecked: !!o.valueGetter(s.fields.startTimezone),
      endZoneChecked: !!o.valueGetter(s.fields.endTimezone)
    };
  },
  render() {
    let o, s, f, k, p, b, g, E, z;
    const V = Ee(this), F = fe(), a = ke(this);
    this.$props;
    const {
      startTimezoneCheckedLabel: _,
      startTimezoneCheckedEditor: A,
      endTimezoneCheckedLabel: B,
      endTimezoneCheckedEditor: q
    } = this.$props, R = i.call(this, this.titleLabel, n.call(this)), G = i.call(this, this.titleError, n.call(this)), $ = i.call(this, this.titleEditor, n.call(this)), N = i.call(this, this.startLabel, n.call(this)), M = i.call(this, this.startError, n.call(this)), K = i.call(this, this.startEditor, n.call(this)), W = i.call(this, this.startTimezoneLabel, n.call(this)), H = i.call(this, this.startTimezoneError, n.call(this)), J = i.call(this, this.startTimezoneEditor, n.call(this)), P = i.call(this, this.endLabel, n.call(this)), Q = i.call(this, this.endError, n.call(this)), U = i.call(this, this.endEditor, n.call(this)), X = i.call(this, this.endTimezoneLabel, n.call(this)), Y = i.call(this, this.endTimezoneError, n.call(this)), ee = i.call(this, this.endTimezoneEditor, n.call(this)), te = i.call(this, this.allDayLabel, n.call(this)), ie = i.call(this, this.allDayEditor, n.call(this)), ne = i.call(this, this.recurrenceEditor, n.call(this)), oe = i.call(this, this.descriptionLabel, n.call(this)), re = i.call(this, this.descriptionEditor, n.call(this)), le = i.call(this, this.descriptionError, n.call(this)), se = i.call(this, this.resourceLabel, n.call(this)), ae = i.call(this, this.resourceEditor, n.call(this)), de = this.kendoForm.valueGetter(this.ks.fields.start) || /* @__PURE__ */ new Date(), ce = this.kendoForm.valueGetter(this.ks.fields.startTimezone) || this.ks.timezone || "", ue = this.kendoForm.valueGetter(this.ks.fields.endTimezone) || this.ks.timezone || "";
    this.requiredValidationMessage = a.toLanguageString(S, c[S]);
    const m = this.ks.fields.title;
    return e(pe, {
      class: "k-scheduler-edit-form"
    }, {
      default: () => [e(d, null, {
        default: () => [e(t, {
          name: m,
          component: R,
          editorId: "k-scheduler-editor-title"
        }, u(o = a.toLanguageString(y, c[y])) ? o : {
          default: () => [o]
        }), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          id: "k-scheduler-editor-title",
          name: m,
          field: m,
          component: $
        }, null), this.kendoForm.errors[m] && e(t, {
          name: m,
          component: G
        }, {
          default: () => [this.kendoForm.errors[m]]
        })])]
      }), e(d, null, {
        default: () => [e(t, {
          name: this.ks.fields.start,
          component: N,
          editorId: "k-scheduler-editor-start",
          class: "k-form-label"
        }, u(s = a.toLanguageString(v, c[v])) ? s : {
          default: () => [s]
        }), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          id: "k-scheduler-editor-start",
          name: this.ks.fields.start,
          width: "auto",
          component: K,
          isAllDay: !!this.kendoForm.values.isAllDay,
          timezone: this.ks.timezone
        }, null), this.kendoForm.errors[this.ks.fields.start] && e(t, {
          name: this.ks.fields.start,
          component: M
        }, {
          default: () => [this.kendoForm.errors[this.ks.fields.start]]
        })])]
      }), e(d, null, {
        default: () => [F.length > 0 && e("div", null, [e(A, {
          id: "k-scheduler-editor-set-start-timezone",
          onChange: this.handleStartZoneCheckboxChange,
          value: this.startZoneChecked
        }, null), e(_, {
          class: "k-checkbox-label",
          editorId: "k-scheduler-editor-set-start-timezone",
          style: {
            display: "inline-flex"
          }
        }, u(f = a.toLanguageString(L, c[L])) ? f : {
          default: () => [f]
        })])]
      }), this.startZoneChecked && e(d, null, {
        default: () => [e(t, {
          name: this.ks.fields.start,
          component: W
        }, u(k = a.toLanguageString(C, c[C])) ? k : {
          default: () => [k]
        }), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          component: J,
          value: ce,
          validator: this.startTimezoneValidator,
          dataItems: F,
          name: this.ks.fields.startTimezone
        }, null), this.kendoForm.errors[this.ks.fields.startTimezone] && e(t, {
          name: this.ks.fields.startTimezone,
          component: H
        }, {
          default: () => [this.kendoForm.errors[this.ks.fields.startTimezone]]
        })])]
      }), e(d, null, {
        default: () => [e(t, {
          name: this.ks.fields.end,
          component: P,
          editorId: "k-scheduler-editor-end",
          class: "k-form-label"
        }, u(p = a.toLanguageString(j, c[j])) ? p : {
          default: () => [p]
        }), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          id: "k-scheduler-editor-end",
          name: this.ks.fields.end,
          width: "auto",
          component: U,
          isAllDay: !!this.kendoForm.values.isAllDay,
          timezone: this.ks.timezone
        }, null), this.kendoForm.errors[this.ks.fields.end] && e(t, {
          name: this.ks.fields.end,
          component: Q
        }, {
          default: () => [this.kendoForm.errors[this.ks.fields.end]]
        })])]
      }), this.startZoneChecked && e(d, null, {
        default: () => [e("div", {
          class: "k-form-field-wrap"
        }, [e(q, {
          id: "k-scheduler-editor-set-end-timezone",
          onChange: this.handleEndZoneCheckboxChange,
          value: this.endZoneChecked
        }, null)]), e(B, {
          class: "k-checkbox-label",
          editorId: "k-scheduler-editor-set-end-timezone",
          style: {
            display: "inline-flex"
          }
        }, u(b = a.toLanguageString(O, c[O])) ? b : {
          default: () => [b]
        })]
      }), this.endZoneChecked && e(d, null, {
        default: () => [e(t, {
          name: this.ks.fields.endTimezone,
          component: X,
          class: "k-form-label"
        }, u(g = a.toLanguageString(Z, c[Z])) ? g : {
          default: () => [g]
        }), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          value: ue,
          dataItems: F,
          validator: this.endTimezoneValidator,
          component: ee,
          name: this.ks.fields.endTimezone
        }, null), this.kendoForm.errors[this.ks.fields.endTimezone] && e(t, {
          name: this.ks.fields.endTimezone,
          component: Y
        }, {
          default: () => [this.kendoForm.errors[this.ks.fields.endTimezone]]
        })])]
      }), e(d, null, {
        default: () => [e(t, {
          name: this.ks.fields.isAllDay,
          component: l,
          class: "k-form-label"
        }, null), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          id: "k-is-allday-checkbox",
          name: this.ks.fields.isAllDay,
          component: ie
        }, null), e(t, {
          name: this.ks.fields.isAllDay,
          field: this.ks.fields.isAllDay,
          editorId: "k-is-allday-checkbox",
          class: "k-checkbox-label",
          component: te
        }, u(E = a.toLanguageString(x, c[x])) ? E : {
          default: () => [E]
        })])]
      }), e("div", {
        class: "k-recurrence-editor"
      }, [e(t, {
        component: ne,
        changeOnInput: !1,
        field: this.ks.fields.recurrenceRule,
        name: this.ks.fields.recurrenceRule,
        start: de
      }, null)]), e(d, null, {
        default: () => [e(t, {
          name: this.ks.fields.description,
          component: oe,
          class: "k-form-label"
        }, u(z = a.toLanguageString(D, c[D])) ? z : {
          default: () => [z]
        }), e("div", {
          class: "k-form-field-wrap"
        }, [e(t, {
          component: re,
          name: this.ks.fields.description,
          rows: 1,
          id: "k-event-description"
        }, null), this.kendoForm.errors[this.ks.fields.description] && e(t, {
          name: this.ks.fields.description,
          component: le
        }, {
          default: () => [this.kendoForm.errors[this.ks.fields.description]]
        })])]
      }), (this.ks.props.resources || []).map(function(r) {
        return e(d, {
          key: r.field
        }, {
          default: () => [e(t, {
            name: r.field,
            component: se,
            class: "k-form-label"
          }, null), e(l, {
            class: "k-form-label"
          }, {
            default: () => [r.name]
          }), e(t, {
            name: r.field,
            component: ae,
            resource: r,
            multiple: r.multiple,
            dataItems: r.data,
            textField: r.textField,
            valueField: r.valueField,
            colorField: r.colorField
          }, null), this.kendoForm.errors[r.field] && e(t, {
            name: r.field,
            component: h
          }, {
            default: () => [this.kendoForm.errors[r.field]]
          })]
        });
      }, this), V]
    });
  },
  methods: {
    handleStartZoneCheckboxChange(o) {
      o.value || (this.$emit("change", this.ks.fields.startTimezone, {
        value: null
      }), this.$emit("change", this.ks.fields.endTimezone, {
        value: null
      }), this.endZoneChecked = o.value), this.startZoneChecked = o.value;
    },
    handleEndZoneCheckboxChange(o) {
      o.value || this.$emit("change", this.ks.fields.endTimezone, {
        value: null
      }), this.endZoneChecked = o.value;
    },
    requiredValidator(o) {
      return o ? void 0 : this.requiredValidationMessage;
    },
    startTimezoneValidator(o, s) {
      return this.startZoneChecked ? this.requiredValidator(s(this.ks.fields.startTimezone)) : void 0;
    },
    endTimezoneValidator(o, s) {
      return this.startZoneChecked && this.endZoneChecked ? this.requiredValidator(s(this.ks.fields.endTimezone)) || this.requiredValidator(s(this.ks.fields.startTimezone)) : void 0;
    }
  }
});
export {
  Ie as SchedulerFormEditor
};
