/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as p, h as m, createVNode as t } from "vue";
import { toSchedulerGroups as u, formatEventTime as c, COLLECTION_ACTION as n } from "../utils/main.mjs";
import { getDefaultSlots as g, getTemplate as $, Draggable as r, Icon as l } from "@progress/kendo-vue-common";
import { provideIntlService as k, provideLocalizationService as b } from "@progress/kendo-vue-intl";
import { deleteTitle as o, messages as f } from "../messages/main.mjs";
import { SchedulerOccurrenceDialog as z } from "../components/SchedulerOccurrenceDialog.mjs";
import { SchedulerRemoveDialog as v } from "../components/SchedulerRemoveDialog.mjs";
import { SchedulerForm as C } from "../components/SchedulerForm.mjs";
import { caretAltRightIcon as a, caretAltLeftIcon as h, arrowRotateCwIcon as S, arrowsNoRepeatIcon as R, xIcon as I } from "@progress/kendo-svg-icons";
import { useEditable as D } from "../hooks/useEditable.mjs";
const N = /* @__PURE__ */ p({
  name: "KendoSchedulerItem",
  inheritAttrs: !1,
  emits: {
    focus: null,
    blur: null,
    mousedown: null,
    mouseup: null,
    mouseover: null,
    mouseout: null,
    mouseenter: null,
    mouseleave: null,
    click: null,
    doubleclick: null,
    removeclick: null,
    keydown: null,
    keypress: null,
    keyup: null,
    press: null,
    drag: null,
    release: null,
    resizepress: null,
    resizestartdrag: null,
    resizeenddrag: null,
    resizerelease: null,
    cancel: null,
    close: null,
    formsubmit: null
  },
  props: {
    uid: [String, Number],
    start: Date,
    end: Date,
    originalStart: Date,
    startTimezone: String,
    endTimezone: String,
    isAllDay: Boolean,
    title: String,
    description: String,
    occurrenceId: String,
    recurrenceExceptions: Array,
    recurrenceRule: String,
    recurrenceId: [String, Number],
    dataItem: Object,
    head: Boolean,
    tail: Boolean,
    order: Number,
    zonedStart: Object,
    zonedEnd: Object,
    slots: Array,
    group: Object,
    range: Object,
    isException: Boolean,
    isRecurring: Boolean,
    id: String,
    tabIndex: Number,
    className: String,
    itemStyle: Object,
    editable: [Object, Boolean],
    selected: Boolean,
    vertical: Boolean,
    dragHint: Boolean,
    resizeHint: Boolean,
    format: String,
    maxSiblingsPerSlot: Number,
    itemTitle: String,
    formItem: Object,
    dragItem: Object,
    resizeItem: Object,
    removeItem: Object,
    ignoreIsAllDay: Boolean,
    item: [String, Function, Object],
    showOccurrenceDialog: {
      type: Boolean,
      default: void 0
    },
    showRemoveDialog: {
      type: Boolean,
      default: void 0
    }
  },
  inject: {
    ks: {
      default: null
    },
    bv: {
      default: null
    },
    kendoLocalizationService: {
      default: null
    },
    kendoIntlService: {
      default: null
    },
    setItems: {
      default: null
    },
    itemClick: {
      default: null
    },
    itemDoubleClick: {
      default: null
    },
    ksCancel: {
      default: null
    },
    ksFormSubmit: {
      default: null
    },
    ksOccurrenceClick: {
      default: null
    },
    ksSeriesClick: {
      default: null
    },
    ksRemoveConfirm: {
      default: null
    }
  },
  computed: {
    currentEditable() {
      return D(this.$props.editable);
    },
    resource() {
      const e = this.$props.group.resources.find((s) => !!(s.colorField && s[s.colorField] !== "" && s[s.colorField] !== void 0)), i = u(void 0, this.ks.props.resources)[0].resources.find((s) => !!(s.colorField && s[s.colorField] !== "" && s[s.colorField] !== void 0 && this.dataItem[s.field] === s.value));
      return e || i;
    },
    color() {
      return this.resource && this.resource.colorField && this.resource[this.resource.colorField];
    },
    currentTabIndex() {
      return this.$props.tabIndex !== void 0 ? this.$props.tabIndex === null ? void 0 : this.$props.tabIndex : this.$props.selected ? 0 : -1;
    },
    itemClassName() {
      return {
        "k-event": !this.$props.resizeHint,
        "k-selected": this.$props.selected && this.currentEditable.select,
        "k-event-drag-hint": this.$props.dragHint,
        "k-scheduler-marquee": this.$props.resizeHint,
        "k-marquee": this.$props.resizeHint,
        "k-first": this.$props.resizeHint && !this.$props.tail,
        "k-last": this.$props.resizeHint && !this.$props.head,
        [this.$props.className]: this.$props.className
      };
    },
    eventLabel() {
      return `${c(this.intl, this.$props.zonedStart, this.$props.zonedEnd, this.$props.isAllDay)}, ${this.$props.title}`;
    },
    computedStyle() {
      return {
        cursor: "pointer",
        userSelect: "none",
        borderColor: this.$props.resizeHint ? void 0 : this.color,
        backgroundColor: this.$props.resizeHint ? void 0 : this.color,
        touchAction: "none",
        ...this.$props.itemStyle
      };
    }
  },
  created() {
    this.setItems({
      type: n.add,
      item: this
    });
  },
  mounted() {
    this.element || (this.element = this.$refs.draggable && this.$refs.draggable.element);
  },
  unmounted() {
    this.setItems({
      type: n.remove,
      item: this
    });
  },
  render() {
    const e = g(this);
    this.intl = k(this);
    const s = b(this).toLanguageString(o, f[o]), d = $.call(this, {
      h: m,
      template: this.bv.viewProps.resizeHint,
      additionalProps: {
        dataItem: this.dataItem,
        color: this.color,
        itemClassName: this.itemClassName
      }
    });
    return t(r, {
      onPress: this.handlePress,
      onDrag: this.handleDrag,
      onRelease: this.handleRelease,
      ref: "draggable"
    }, {
      default: () => [t("div", {
        id: this.$props.id,
        style: this.computedStyle,
        tabindex: this.currentTabIndex,
        class: this.itemClassName,
        role: "button",
        "aria-label": this.eventLabel,
        onFocusin: this.handleFocus,
        onBlur: this.handleBlur,
        onMouseup: this.handleMouseUp,
        onMousedown: this.handleMouseDown,
        onClick: this.handleClick,
        onMouseover: this.handleMouseOver,
        onMouseout: this.handleMouseOut,
        onMouseenter: this.handleMouseEnter,
        onMouseleave: this.handleMouseLeave,
        onDblclick: this.handleDoubleClick,
        onKeydown: this.handleKeyDown,
        onKeypress: this.handleKeyPress,
        onKeyup: this.handleKeyUp,
        "data-group-index": this.$props.group.index,
        "data-range-index": this.$props.range.index
      }, [!this.$props.resizeHint && t("span", {
        class: "k-event-actions"
      }, [this.$props.tail && t(l, {
        name: this.ks.isRtl ? "caret-alt-right" : "caret-alt-left",
        icon: this.ks.isRtl ? a : h,
        size: "medium"
      }, null), this.$props.isRecurring && !this.$props.isException && t(l, {
        name: "arrow-rotate-cw",
        icon: S,
        size: "medium"
      }, null), !this.$props.isRecurring && this.$props.isException && t(l, {
        name: "arrows-no-repeat",
        icon: R,
        size: "medium"
      }, null)]), this.formItem && !this.showOccurrenceDialog && this.currentEditable.edit && t(C, {
        dataItem: this.formItem,
        onSubmit: this.handleFormSubmit,
        onClose: this.handleFormClose,
        onCancel: this.handleFormCancel
      }, null), this.showOccurrenceDialog && this.currentEditable.edit && t(z, {
        dataItem: this.formItem || this.dragItem || this.resizeItem || this.removeItem,
        isRemove: !!this.removeItem,
        onClose: this.ksCancel,
        onOccurrenceclose: this.ksOccurrenceClick,
        onSeriesclose: this.ksSeriesClick
      }, null), this.showRemoveDialog && this.removeItem && this.currentEditable.remove && t(v, {
        dataItem: this.removeItem,
        onClose: this.ksCancel,
        onCancel: this.ksCancel,
        onConfirm: this.ksRemoveConfirm
      }, null), e, !this.$props.resizeHint && t("span", {
        class: "k-event-actions"
      }, [this.currentEditable.remove && t("a", {
        tabindex: -1,
        "aria-hidden": "true",
        class: "k-link k-event-delete",
        title: s,
        "aria-label": s,
        onClick: this.handleRemoveClick
      }, [t(l, {
        name: "x",
        icon: I,
        size: "medium"
      }, null)]), this.$props.head && t(l, {
        name: this.ks.isRtl ? "caret-alt-left" : "caret-alt-right",
        icon: this.ks.isRtl ? h : a,
        size: "medium"
      }, null)]), this.currentEditable.resize && this.$props.vertical && [t(r, {
        onPress: this.handleResizePress,
        onDrag: this.handleResizeStartDrag,
        onRelease: this.handleResizeRelease
      }, {
        default: () => [t("span", {
          class: "k-resize-handle k-resize-n"
        }, null)]
      }), t(r, {
        onPress: this.handleResizePress,
        onDrag: this.handleResizeEndDrag,
        onRelease: this.handleResizeRelease
      }, {
        default: () => [t("span", {
          class: "k-resize-handle k-resize-s"
        }, null)]
      })], this.currentEditable.resize && !this.$props.vertical && [t(r, {
        onPress: this.handleResizePress,
        onDrag: this.handleResizeStartDrag,
        onRelease: this.handleResizeRelease
      }, {
        default: () => [t("span", {
          class: "k-resize-handle k-resize-w"
        }, null)]
      }), t(r, {
        onPress: this.handleResizePress,
        onDrag: this.handleResizeEndDrag,
        onRelease: this.handleResizeRelease
      }, {
        default: () => [t("span", {
          class: "k-resize-handle k-resize-e"
        }, null)]
      })], this.$props.resizeHint ? this.bv.viewProps.resizeHint ? d : [t("div", {
        class: "k-marquee-color",
        style: {
          borderColor: this.color,
          backgroundColor: this.color
        }
      }, null), t("div", {
        class: "k-marquee-text"
      }, [!this.$props.tail && t("div", {
        class: "k-label-top"
      }, [this.intl.formatDate(this.$props.zonedStart, this.$props.format)]), !this.$props.head && t("div", {
        class: "k-label-bottom"
      }, [this.intl.formatDate(this.$props.zonedEnd, this.$props.format)])])] : null])]
    });
  },
  methods: {
    getElement() {
      return this.$el.nodeType === 8 ? this.$el.parentElement : this.$el.nodeType === 3 ? this.$el.nextElementSibling : this.$el;
    },
    // Focus Handlers
    handleFocus(e) {
      this.$emit("focus", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleBlur(e) {
      this.$emit("blur", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    // Mouse Handlers
    handleMouseDown(e) {
      this.$emit("mousedown", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleClick(e) {
      const i = {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      };
      this.$emit("click", i), this.itemClick(i);
    },
    handleMouseUp(e) {
      this.$emit("mouseup", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleMouseOver(e) {
      this.$emit("mouseover", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleMouseOut(e) {
      this.$emit("mouseout", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleMouseEnter(e) {
      this.$emit("mouseenter", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleMouseLeave(e) {
      this.$emit("mouseleave", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleDoubleClick(e) {
      const i = {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      };
      this.$emit("doubleclick", i), this.itemDoubleClick(i);
    },
    handleRemoveClick(e) {
      this.$emit("removeclick", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    // Keyboard Handlers
    handleKeyDown(e) {
      this.$emit("keydown", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleKeyPress(e) {
      this.$emit("keypress", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleKeyUp(e) {
      this.$emit("keyup", {
        event: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    // Drag Handlers
    handlePress(e) {
      this.currentEditable.drag && this.$emit("press", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleDrag(e) {
      this.currentEditable.drag && this.$emit("drag", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleRelease(e) {
      this.currentEditable.drag && this.$emit("release", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleResizePress(e) {
      this.$emit("resizepress", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleResizeStartDrag(e) {
      this.$emit("resizestartdrag", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleResizeEndDrag(e) {
      this.$emit("resizeenddrag", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleResizeRelease(e) {
      this.$emit("resizerelease", {
        dragEvent: e,
        target: {
          props: {
            ...this.$props
          },
          element: this.element
        }
      });
    },
    handleFormClose(e) {
      this.ksCancel(e), this.$emit("close", e);
    },
    handleFormSubmit(e) {
      this.ksFormSubmit(e), this.$emit("formsubmit", e);
    },
    handleFormCancel(e) {
      this.ksCancel(e), this.$emit("cancel", e);
    }
  }
});
export {
  N as SchedulerItem
};
