/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as v, createVNode as c, h as I, isVNode as D } from "vue";
import { SchedulerItem as y } from "./SchedulerItem.mjs";
import { intersects as S, first as w, calculateOrder as k } from "../utils/main.mjs";
import { getRect as u, setRect as f } from "../views/common/utils.mjs";
import { BORDER_WIDTH as a } from "../constants/main.mjs";
import { provideIntlService as O } from "@progress/kendo-vue-intl";
import { SchedulerItemContent as $ } from "./SchedulerItemContent.mjs";
import { canUseDOM as b, getDefaultSlots as E, getTemplate as F } from "@progress/kendo-vue-common";
function z(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !D(e);
}
const x = 1, N = /* @__PURE__ */ v({
  name: "KendoSchedulerViewItem",
  inheritAttrs: !1,
  props: {
    ignoreIsAllDay: Boolean,
    item: [String, Function, Object],
    uid: [String, Number],
    start: Date,
    end: Date,
    originalStart: Date,
    startTimezone: String,
    endTimezone: String,
    isAllDay: Boolean,
    title: String,
    description: String,
    occurrenceId: String,
    recurrenceExceptions: Array,
    recurrenceRule: String,
    recurrenceId: [String, Number],
    dataItem: Object,
    head: Boolean,
    tail: Boolean,
    order: Number,
    zonedStart: Object,
    zonedEnd: Object,
    slots: Array,
    group: Object,
    range: Object,
    isException: Boolean,
    isRecurring: Boolean,
    id: String,
    tabIndex: Number,
    className: String,
    itemStyle: Object,
    editable: [Object, Boolean],
    selected: Boolean,
    vertical: Boolean,
    dragHint: Boolean,
    resizeHint: Boolean,
    format: String,
    showOccurrenceDialog: {
      type: Boolean,
      default: void 0
    },
    showRemoveDialog: {
      type: Boolean,
      default: void 0
    },
    formItem: Object,
    dragItem: Object,
    resizeItem: Object,
    removeItem: Object,
    itemRef: Object,
    onKeydown: Function,
    onKeyup: Function,
    onFocus: Function,
    onMouseup: Function,
    onMousedown: Function,
    onClick: Function,
    onDoubleclick: Function,
    onRemoveclick: Function,
    onPress: Function,
    onDrag: Function,
    onRelease: Function,
    onResizepress: Function,
    onResizeenddrag: Function,
    onResizestartdrag: Function,
    onResizerelease: Function
  },
  inject: {
    kendoIntlService: {
      default: null
    },
    ks: {
      default: null
    },
    bv: {
      default: null
    }
  },
  computed: {
    itemTime() {
      return this.$props.isAllDay ? this.intl.toString(this.$props.zonedStart, "t") : this.intl.format("{0:t} - {1:t}", this.$props.zonedStart, this.$props.zonedEnd);
    },
    itemTitle() {
      return `(${this.itemTime}): ${this.$props.title}`;
    }
  },
  data() {
    return {
      timeout: void 0,
      currentItem: null,
      viewItem: null,
      display: !0,
      visible: !1,
      maxSiblingsPerSlot: 0
    };
  },
  mounted() {
    this.element = this.getElement(), !(!this.ks.scheduler || !this.ks.scheduler.$el) && b && (this.observer = new window.ResizeObserver(this.handleResize), this.observer.observe(this.ks.scheduler.$el));
  },
  updated() {
    const e = this;
    this.$nextTick(function() {
      e.align(), e.position();
    }), !(!this.ks.scheduler || !this.ks.scheduler.$el || this.observer) && b && window.ResizeObserver && (this.observer = new window.ResizeObserver(this.handleResize), this.observer.observe(this.ks.scheduler.$el));
  },
  unmounted() {
    this.observer && this.observer.disconnect();
  },
  render() {
    const e = E(this);
    this.intl = O(this);
    let t;
    const r = c(y, {
      ignoreIsAllDay: this.ignoreIsAllDay,
      item: this.item,
      uid: this.uid,
      start: this.start,
      end: this.end,
      originalStart: this.originalStart,
      startTimezone: this.startTimezone,
      endTimezone: this.endTimezone,
      isAllDay: this.isAllDay,
      title: this.title,
      description: this.description,
      occurrenceId: this.occurrenceId,
      recurrenceExceptions: this.recurrenceExceptions,
      recurrenceRule: this.recurrenceRule,
      recurrenceId: this.recurrenceId,
      dataItem: this.dataItem,
      head: this.head,
      tail: this.tail,
      order: this.order,
      zonedStart: this.zonedStart,
      zonedEnd: this.zonedEnd,
      slots: this.slots,
      group: this.group,
      range: this.range,
      isException: this.isException,
      isRecurring: this.isRecurring,
      id: this.id,
      tabIndex: this.tabIndex,
      className: this.className,
      itemStyle: {
        visibility: this.visible ? void 0 : "hidden",
        display: this.display ? void 0 : "none",
        ...this.$props.itemStyle
      },
      editable: this.editable,
      selected: this.selected,
      vertical: this.vertical,
      dragHint: this.dragHint,
      resizeHint: this.resizeHint,
      format: this.format,
      itemTitle: this.itemTitle,
      showOccurrenceDialog: this.showOccurrenceDialog,
      showRemoveDialog: this.showRemoveDialog,
      formItem: this.formItem,
      dragItem: this.dragItem,
      resizeItem: this.resizeItem,
      removeItem: this.removeItem,
      maxSiblingsPerSlot: this.maxSiblingsPerSlot,
      onKeydown: this.handleKeyDown,
      onKeyup: this.handleKeyUp,
      onFocus: this.handleFocus,
      onMouseup: this.handleMouseUp,
      onMousedown: this.handleMouseDown,
      onClick: this.handleClick,
      onDoubleclick: this.handleDoubleClick,
      onRemoveclick: this.handleRemoveClick,
      onPress: this.handlePress,
      onDrag: this.handleDrag,
      onRelease: this.handleRelease,
      onResizepress: this.handleResizePress,
      onResizeenddrag: this.handleResizeEndDrag,
      onResizestartdrag: this.handleResizeStartDrag,
      onResizerelease: this.handleResizeRelease
    }, {
      default: () => [!this.$props.resizeHint && c("div", {
        title: this.itemTitle
      }, [!this.$props.isAllDay && c($, {
        title: this.itemTitle,
        class: "k-event-template k-event-time "
      }, z(e) ? e : {
        default: () => [e]
      }), c($, {
        title: this.$props.title,
        class: "k-event-template"
      }, z(e) ? e : {
        default: () => [e]
      })])]
    });
    return t = F.call(this, {
      h: I,
      template: this.$props.item,
      defaultRendering: r,
      defaultSlots: e,
      additionalListeners: {
        //   keydown: this.handleKeyDown,
        // keyup: this.handleKeyUp,
        // Focus
        //  focus: this.handleFocus,
        // Mouse
        // mouseup: this.handleMouseUp,
        // mousedown: this.handleMouseDown,
        //  click: this.handleClick,
        doubleclick: this.handleDoubleClick,
        removeclick: this.handleRemoveClick,
        // Drag
        press: this.handlePress,
        drag: this.handleDrag,
        release: this.handleRelease,
        // Resize
        resizepress: this.handleResizePress,
        resizeenddrag: this.handleResizeEndDrag,
        resizestartdrag: this.handleResizeStartDrag,
        resizerelease: this.handleResizeRelease
      }
    }), t;
  },
  methods: {
    getElement() {
      return this.$el.nodeType === 8 ? this.$el.parentElement : this.$el.nodeType === 3 ? this.$el.nextElementSibling : this.$el;
    },
    // Focus Handlers
    handleFocus(e) {
      this.$emit("focus", e);
    },
    handleBlur(e) {
      this.$emit("blur", e);
    },
    // Mouse Handlers
    handleMouseDown(e) {
      this.$emit("mousedown", e);
    },
    handleClick(e) {
      this.$emit("click", e);
    },
    handleMouseUp(e) {
      this.$emit("mouseup", e);
    },
    handleMouseOver(e) {
      this.$emit("mouseover", e);
    },
    handleMouseOut(e) {
      this.$emit("mouseout", e);
    },
    handleMouseEnter(e) {
      this.$emit("mouseenter", e);
    },
    handleMouseLeave(e) {
      this.$emit("mouseleave", e);
    },
    handleDoubleClick(e) {
      this.$emit("doubleclick", e);
    },
    handleRemoveClick(e) {
      this.$emit("removeclick", e);
    },
    // Keyboard Handlers
    handleKeyDown(e) {
      this.$emit("keydown", e);
    },
    handleKeyPress(e) {
      this.$emit("keypress", e);
    },
    handleKeyUp(e) {
      this.$emit("keyup", e);
    },
    // Drag Handlers
    handlePress(e) {
      this.$emit("press", e);
    },
    handleDrag(e) {
      this.$emit("drag", e);
    },
    handleRelease(e) {
      this.$emit("release", e);
    },
    handleResizePress(e) {
      this.$emit("resizepress", e);
    },
    handleResizeStartDrag(e) {
      this.$emit("resizestartdrag", e);
    },
    handleResizeEndDrag(e) {
      this.$emit("resizeenddrag", e);
    },
    handleResizeRelease(e) {
      this.$emit("resizerelease", e);
    },
    calculateMostSiblings(e, t) {
      let r = 1;
      return e.forEach((s) => {
        const n = t.filter((h) => this.inSlot(s.cSlot, h.$props));
        n.length > r && (r = n.length);
      }), r;
    },
    getSiblingsInAllSlots(e, t) {
      return e.map((s) => t.filter((n) => this.inSlot(s.cSlot, n.$props)));
    },
    inSlot(e, t) {
      return S(e.start, e.end, t.start, t.end) && e.group.index === t.group.index && e.range.index === t.range.index && (this.$props.ignoreIsAllDay || e.isAllDay === t.isAllDay);
    },
    align() {
      if (!this.element)
        return;
      const e = (this.bv.slots || []).filter((s) => s && this.inSlot(s.cSlot, this.$props));
      if (e.length === 0) {
        this.display = !1;
        return;
      }
      const t = w(e.sort(function(s, n) {
        return s.cSlot.start && n.cSlot.start ? s.cSlot.start.getTime() - n.cSlot.start.getTime() : !0;
      }));
      if (!t)
        return;
      const r = u(t.$el);
      f(this.element, r);
    },
    position() {
      if (!this.element)
        return;
      const e = (this.bv.slots || []).filter((o) => o && this.inSlot(o.cSlot, this.$props)), t = [], r = [], s = [];
      (this.bv.items || []).forEach((o) => {
        o && (o.$props.dragHint ? r.push(o) : o.$props.resizeHint ? s.push(o) : t.push(o));
      });
      const n = this.$props.dragHint || this.$props.resizeHint ? k(this, this.$props.dragHint ? r : s, e, this.$props.ignoreIsAllDay) : this.$props.order || 0;
      let h = this.$props.dragHint || this.$props.resizeHint ? this.calculateMostSiblings(e, this.$props.dragHint ? r : s) : this.calculateMostSiblings(e, t);
      const R = this.getSiblingsInAllSlots(e, t);
      let p = 0;
      const i = u(this.element);
      if (R.forEach((o) => {
        let m = 0;
        o.sort(function(l, d) {
          return l.$props.order - d.$props.order;
        }).forEach((l) => {
          S(l.$props.start, l.$props.end, this.$props.start, this.$props.end) && !(this.$props.dragHint || this.$props.resizeHint) && l.$props.maxSiblingsPerSlot && l.$props.maxSiblingsPerSlot > h && l.getElement() !== this.element && (h = l.$props.maxSiblingsPerSlot);
          const d = u(l.getElement());
          l.$props.order !== null && l.$props.order < n && (m = (d.top || i.top) + d.height - i.top - a * n + x);
        }), m > p && (p = m);
      }), e.length === 0) {
        this.display = !1;
        return;
      }
      const g = 20;
      i.width = this.$props.vertical ? i.width / h - a - g / h : i.width * e.length - a - g, i.height = this.$props.vertical ? i.height * e.length - a : (this.$props.resizeHint || this.$props.dragHint) && h <= 1 ? i.height : this.$props.itemStyle && this.$props.itemStyle.height ? this.$props.itemStyle.height : 25, i.left = this.$props.vertical ? i.left + n * i.width + a * n : i.left, i.top = this.$props.vertical ? i.top : i.top + p + a * n, this.maxSiblingsPerSlot = h, f(this.element, i), this.visible = !0, this.display = !0;
    },
    handleResize() {
      this.timeout !== void 0 && window.cancelAnimationFrame(this.timeout), this.timeout = window.requestAnimationFrame(() => {
        this.align(), this.position();
      });
    }
  }
});
export {
  N as SchedulerViewItem
};
