/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as W, createVNode as a, isVNode as z } from "vue";
import { provideIntlService as E, provideLocalizationService as I } from "@progress/kendo-vue-intl";
import { FieldWrapper as r } from "@progress/kendo-vue-form";
import { recurrenceEditorRepeat as k, messages as v, recurrenceEditorWeeklyRepeatOn as x, recurrenceEditorMonthlyRepeatOn as S, recurrenceEditorMonthlyDay as j, recurrenceEditorYearlyRepeatOn as q, recurrenceEditorEndLabel as H, recurrenceEditorEndNever as $, recurrenceEditorEndAfter as L, recurrenceEditorEndOn as U, recurrenceEditorYearlyOf as F, recurrenceEditorEndOccurrence as _ } from "../messages/main.mjs";
import { serializeRule as K } from "@progress/kendo-recurrence";
import { ZonedDate as g, toLocalDate as P } from "@progress/kendo-date-math";
import { RecurrenceFrequencyEditor as N } from "./RecurrenceFrequencyEditor.mjs";
import { RecurrenceRepeatOnWeekEditor as V } from "./RecurrenceRepeatOnWeekEditor.mjs";
import { getRule as T, getFrequencies as Y, getFrequency as A, getExtendedWeekDays as B, getWeekDay as G, getMonths as Z, getMonth as J, getOffsets as Q, getOffset as X, getEndRule as ee, getMonthDay as te, getUntil as ae, getWeekDays as ne, getRepeatOnRule as le, capitalize as p, weekDayRuleFromString as b } from "./common.mjs";
import { Label as l } from "@progress/kendo-vue-labels";
import { NumericTextBox as d, RadioGroup as m } from "@progress/kendo-vue-inputs";
import { DropDownList as o } from "@progress/kendo-vue-dropdowns";
import { DatePicker as se } from "@progress/kendo-vue-dateinputs";
function s(t) {
  return typeof t == "function" || Object.prototype.toString.call(t) === "[object Object]" && !z(t);
}
const pe = /* @__PURE__ */ W({
  name: "KendoRecurrenceEditor",
  emits: {
    change: null
  },
  props: {
    name: String,
    value: {
      type: String,
      default: ""
    },
    start: Date,
    timezone: String
  },
  inject: {
    ks: {
      default: null
    },
    kendoLocalizationService: {
      default: null
    },
    kendoIntlService: {
      default: null
    }
  },
  computed: {
    rrule() {
      return T(this.$props.value);
    },
    frequencies() {
      return Y(this.localizeMessage);
    },
    frequency() {
      return A(this.rrule);
    },
    extendedWeekDays() {
      return B(this.intl, this.localizeMessage);
    },
    weekDay() {
      return G(this.extendedWeekDays, this.rrule, this.$props.start);
    },
    months() {
      return Z(this.intl);
    },
    month() {
      return J(this.months, this.rrule);
    },
    offsets() {
      return Q(this.localizeMessage);
    },
    offset() {
      return X(this.offsets, this.rrule);
    },
    endRule() {
      return ee(this.rrule);
    },
    monthDay() {
      return te(this.rrule, this.$props.start);
    },
    until() {
      return ae(this.rrule);
    },
    weekDays() {
      return ne(this.intl);
    },
    repeatOnRule() {
      return le(this.rrule);
    }
  },
  data() {
    return {
      defaultCount: 1,
      defaultUntil: g.fromUTCDate(this.$props.start)
    };
  },
  render() {
    let t, e, n, h, y, c, f;
    this.intl = E(this), this.localization = I(this), this.ks.timezone;
    const i = {
      display: "flex",
      alignItems: "center",
      minHeight: 30
    }, C = function() {
      return [a(o, {
        key: "weekday-offset",
        textField: "text",
        dataItemKey: "value",
        disabled: this.repeatOnRule !== "weekday",
        dataItems: this.offsets,
        value: this.offset,
        onChange: this.handleOffsetChange,
        style: {
          width: "auto"
        }
      }, null), a(o, {
        key: "weekday-value",
        disabled: this.repeatOnRule !== "weekday",
        value: this.weekDay,
        dataItems: this.extendedWeekDays,
        onChange: this.handleWeekDayChange,
        textField: "text",
        dataItemKey: "value",
        style: {
          width: "auto"
        }
      }, null)];
    }, D = function() {
      return a(d, {
        key: "weekday-day",
        min: 1,
        max: 31,
        disabled: this.repeatOnRule !== "monthday",
        value: this.rrule && this.rrule.byMonthDay && this.rrule.byMonthDay[0],
        onChange: this.handleMonthDayChange,
        style: {
          width: "auto"
        }
      }, null);
    }, w = function() {
      return [a(o, {
        key: "monthday-month",
        disabled: this.repeatOnRule !== "monthday",
        value: this.month,
        dataItems: this.months,
        textField: "text",
        dataItemKey: "value",
        onChange: this.handleMonthChange,
        style: {
          width: "auto"
        }
      }, null), a(d, {
        key: "monthday-day",
        min: 1,
        max: 31,
        disabled: this.repeatOnRule !== "monthday",
        value: this.monthDay,
        onChange: this.handleMonthDayChange,
        style: {
          width: "auto"
        }
      }, null)];
    }, R = function() {
      return [a(o, {
        key: "yearly-weekday-offset",
        textField: "text",
        dataItemKey: "value",
        disabled: this.repeatOnRule !== "weekday",
        dataItems: this.offsets,
        value: this.offset,
        onChange: this.handleOffsetChange,
        style: {
          width: "auto"
        }
      }, null), a(o, {
        key: "yearly-weekday-day",
        textField: "text",
        dataItemKey: "value",
        disabled: this.repeatOnRule !== "weekday",
        value: this.weekDay,
        dataItems: this.extendedWeekDays,
        onChange: this.handleWeekDayChange,
        style: {
          width: "auto"
        }
      }, null), a("span", {
        key: "yearly-weekday-of-label"
      }, [this.localizeMessage(F, !0)]), a(o, {
        key: "yearly-weekday-month",
        textField: "text",
        dataItemKey: "value",
        disabled: this.repeatOnRule !== "weekday",
        value: this.month,
        dataItems: this.months,
        onChange: this.handleMonthChange,
        style: {
          width: "auto"
        }
      }, null)];
    }, O = function() {
      let u;
      return [a(d, {
        key: "endrule-after-editor",
        id: "k-endrule-after",
        min: 1,
        style: {
          width: "70px"
        },
        value: this.endRule === "count" ? this.rrule.count : this.defaultCount,
        onChange: this.handleCountChange,
        disabled: this.endRule !== "count"
      }, null), a(l, {
        key: "endrule-after-label",
        class: "k-radio-label",
        editorId: "k-endrule-after"
      }, s(u = this.localizeMessage(_, !0)) ? u : {
        default: () => [u]
      })];
    }, M = () => a(se, {
      key: "k-endrule-until-editor",
      id: "k-endrule-until",
      disabled: this.endRule !== "until",
      min: this.$props.start,
      value: this.endRule === "until" ? this.until : P(this.defaultUntil),
      onChange: this.handleUntilChange,
      style: {
        width: "auto"
      }
    }, null);
    return a("div", null, [a(r, null, {
      default: () => [a(l, {
        class: "k-form-label"
      }, s(t = this.localization.toLanguageString(k, v[k])) ? t : {
        default: () => [t]
      }), a("div", {
        class: "k-form-field-wrap"
      }, [a(N, {
        value: this.frequency,
        dataItems: this.frequencies,
        onChange: this.handleFrequencyChange
      }, null)])]
    }), this.frequency !== "never" && a(r, null, {
      default: () => [a(l, {
        editorId: "interval-editor",
        class: "k-form-label"
      }, s(e = this.localizeMessage(p(this.frequency) + "RepeatEvery")) ? e : {
        default: () => [e]
      }), a("div", {
        class: "k-form-field-wrap"
      }, [a(d, {
        min: 1,
        step: 1,
        defaultValue: 1,
        value: this.rrule.interval,
        onChange: this.handleIntervalChange,
        id: "interval-editor"
      }, null), a(l, {
        editorId: "interval-editor"
      }, s(n = this.localizeMessage(p(this.frequency) + "Interval")) ? n : {
        default: () => [n]
      })])]
    }), this.frequency === "weekly" && a(r, null, {
      default: () => [a(l, {
        class: "k-form-label"
      }, s(h = this.localizeMessage(x, !0)) ? h : {
        default: () => [h]
      }), a("div", {
        class: "k-form-field-wrap"
      }, [a(V, {
        dataItems: this.weekDays,
        value: (this.rrule.byWeekDay || []).map(({
          day: u
        }) => u),
        onChange: this.handleWeekDaysChange
      }, null)])]
    }), this.frequency === "monthly" && a(r, null, {
      default: () => [a(l, {
        key: "recurrence-repeat-on-monthly-label",
        class: "k-form-label"
      }, s(y = this.localizeMessage(S, !0)) ? y : {
        default: () => [y]
      }), a("div", {
        class: "k-form-field-wrap"
      }, [a(m, {
        value: this.repeatOnRule,
        onChange: this.handleRepeatOnRuleChange,
        class: "k-reset",
        dataItems: [{
          value: "monthday",
          style: i,
          label: this.localizeMessage(j, !0),
          content: D.call(this)
        }, {
          value: "weekday",
          style: i,
          label: " ",
          content: C.call(this)
        }]
      }, null)])]
    }), this.frequency === "yearly" && a(r, null, {
      default: () => [a(l, {
        class: "k-form-label"
      }, s(c = this.localizeMessage(q, !0)) ? c : {
        default: () => [c]
      }), a("div", {
        class: "k-form-field-wrap"
      }, [a(m, {
        value: this.repeatOnRule,
        onChange: this.handleRepeatOnRuleChange,
        class: "k-reset",
        dataItems: [{
          value: "monthday",
          label: " ",
          style: i,
          content: w.call(this)
        }, {
          value: "weekday",
          label: " ",
          style: i,
          content: R.call(this)
        }]
      }, null)])]
    }), this.frequency !== "never" && a(r, null, {
      default: () => [a(l, {
        class: "k-form-label"
      }, s(f = this.localizeMessage(H, !0)) ? f : {
        default: () => [f]
      }), a("div", {
        class: "k-form-field-wrap"
      }, [a(m, {
        value: this.endRule,
        onChange: this.handleEndRuleChange,
        dataItems: [{
          value: "never",
          style: i,
          label: this.localizeMessage($, !0)
        }, {
          value: "count",
          style: i,
          label: this.localizeMessage(L, !0),
          content: O.call(this)
        }, {
          value: "until",
          style: i,
          label: this.localizeMessage(U, !0),
          content: M.call(this)
        }]
      }, null)])]
    })]);
  },
  methods: {
    localizeMessage(t, e) {
      const n = e ? t : "scheduler.recurrenceEditor" + t;
      return this.localization.toLanguageString(n, v[n]);
    },
    onChangeHandler(t) {
      t.freq === "never" ? this.$emit("change", {
        value: null
      }) : (t.weekStart === void 0 && (t.weekStart = this.intl.firstDay()), this.$emit("change", {
        value: K(t, this.$props.timezone)
      }));
    },
    handleFrequencyChange(t) {
      const e = {};
      e.freq = t, e.interval = 1, t === "weekly" && (e.byWeekDay = [{
        day: g.fromLocalDate(this.$props.start, this.timezone).getDay(),
        offset: 0
      }]), (t === "monthly" || t === "yearly") && (e.byMonthDay = [this.$props.start.getDate()]), t === "yearly" && (e.byMonth = [this.$props.start.getMonth() + 1]), this.onChangeHandler(e);
    },
    handleIntervalChange(t) {
      const e = t.value;
      this.onChangeHandler(Object.assign({}, this.rrule, {
        interval: e
      }));
    },
    handleCountChange(t) {
      const e = t.value;
      this.onChangeHandler(Object.assign({}, this.rrule, {
        count: e
      })), e !== null && (this.defaultCount = e);
    },
    handleUntilChange(t) {
      const e = t.value;
      if (!e)
        return;
      const n = g.fromLocalDate(e, this.$props.timezone);
      this.onChangeHandler(Object.assign({}, this.rrule, {
        until: n
      })), this.defaultUntil = n;
    },
    handleWeekDaysChange(t) {
      this.onChangeHandler(Object.assign({}, this.rrule, {
        byWeekDay: this.weekDays.filter((e) => t.some((n) => n === e.value)).map((e) => ({
          offset: 0,
          day: e.value
        }))
      }));
    },
    handleWeekDayChange(t) {
      const e = Object.assign({}, this.rrule), n = t.target.value;
      typeof n.value == "string" ? (e.byWeekDay = b(n.value), e.bySetPosition = [this.offset.value]) : e.byWeekDay = [{
        day: n.value,
        offset: this.offset.value
      }], this.onChangeHandler(e);
    },
    handleMonthDayChange(t) {
      this.onChangeHandler(Object.assign({}, this.rrule, {
        byMonthDay: [t.value]
      }));
    },
    handleMonthChange(t) {
      const e = t.value;
      this.onChangeHandler(Object.assign({}, this.rrule, {
        byMonth: [e.value]
      }));
    },
    handleEndRuleChange(t) {
      const e = t.value, n = Object.assign({}, this.rrule);
      switch (e) {
        case "never":
          n.until = void 0, n.count = void 0;
          break;
        case "count":
          n.until = void 0, n.count = this.defaultCount;
          break;
        case "until":
          n.until = this.defaultUntil, n.count = void 0;
          break;
      }
      this.onChangeHandler(n);
    },
    handleRepeatOnRuleChange(t) {
      const e = Object.assign({}, this.rrule);
      t.value === "monthday" ? (e.byWeekDay = void 0, e.bySetPosition = void 0, e.byMonthDay = [this.monthDay]) : t.value === "weekday" && (e.byMonthDay = void 0, typeof this.weekDay.value == "string" ? (e.bySetPosition = [this.offset.value], e.byWeekDay = b(this.weekDay.value)) : e.byWeekDay = [{
        day: this.weekDay.value,
        offset: this.offset.value
      }]), this.onChangeHandler(e);
    },
    handleOffsetChange(t) {
      const e = Object.assign({}, this.rrule), n = t.value;
      if (e.byWeekDay)
        switch (e.byWeekDay.length) {
          case 7:
          case 5:
          case 2:
            e.bySetPosition = [n.value];
            break;
          case 1:
            e.byWeekDay[0].offset = n.value;
            break;
        }
      this.onChangeHandler(e);
    }
  }
});
export {
  pe as RecurrenceEditor
};
