/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as C, createVNode as x, h as O, isVNode as T } from "vue";
import { getDefaultSlots as A, getTemplate as j, Keys as i } from "@progress/kendo-vue-common";
import { DATA_ACTION as N } from "../constants/main.mjs";
import { compareSlots as b, setField as l, isGroupped as $, getField as _, findFirstItem as z, findCurrentItem as R, getSortedSlots as W } from "../utils/main.mjs";
import { SchedulerViewSlot as B } from "./SchedulerViewSlot.mjs";
import { SLOTS_SELECT_ACTION as K } from "../hooks/use-slots-selection.mjs";
import { ITEMS_SELECT_ACTION as L } from "../hooks/use-items-selection.mjs";
import { useEditable as M } from "../hooks/useEditable.mjs";
import { ITEMS_FOCUS_ACTION as P } from "../hooks/use-items-focus.mjs";
import { SLOTS_FOCUS_ACTION as r } from "../hooks/use-slots-focus.mjs";
function H(t) {
  return typeof t == "function" || Object.prototype.toString.call(t) === "[object Object]" && !T(t);
}
const et = /* @__PURE__ */ C({
  name: "KendoSchedulerEditSlot",
  inheritAttrs: !1,
  props: {
    tabIndex: {
      type: Number,
      default: void 0
    },
    className: String,
    form: Object,
    formItem: Object,
    refTo: [Function, Object],
    items: Array,
    row: Number,
    group: Object,
    range: Object,
    isWorkDay: {
      type: Boolean,
      default: !0
    },
    isWorkHour: {
      type: Boolean,
      default: !0
    },
    selected: Boolean,
    col: Number,
    index: Number,
    start: Date,
    end: Date,
    zonedStart: Object,
    zonedEnd: Object,
    isAllDay: Boolean,
    expandable: [Boolean, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    navDay: Boolean,
    editable: [Object, Boolean],
    itemsPerSlot: Number,
    onDataaction: Function
  },
  created() {
    this.slot = null, this.editableSlot = null;
  },
  provide() {
    return {
      ksEditFormSubmit: this.handleEditFormSubmit,
      ksEditFormCancel: this.handleEditFormCancel,
      ksEditFormClose: this.handleEditFormClose
    };
  },
  inject: {
    bv: {
      default: null
    },
    ks: {
      default: null
    },
    dispatchSelectedItems: {
      default: null
    },
    dispatchFocusedItems: {
      default: null
    },
    dispatchFocusedSlots: {
      default: null
    },
    dispatchSelectedSlots: {
      default: null
    },
    ksSlots: {
      default: {}
    }
  },
  data() {
    return {
      currentFormItem: null
    };
  },
  computed: {
    cSlot() {
      return this.ksSlots.cSlots ? this.ksSlots.cSlots[this.index] : {};
    },
    currentTabIndex() {
      const t = this.bv.slots.length && b(this.bv.slots[0].cSlot, this.cSlot);
      return this.$props.tabIndex !== void 0 ? this.$props.tabIndex === null ? void 0 : this.$props.tabIndex : this.bv.selectedSlots.length === 0 && t && this.cSlot.items.length === 0 ? 0 : void 0;
    },
    computedEditable() {
      return M(this.$props.editable);
    },
    compFormItem() {
      return this.formItem !== void 0 ? this.formItem : this.currentFormItem;
    }
  },
  render() {
    const t = A(this), {
      viewSlot: e,
      form: s,
      formItem: o,
      items: n,
      row: I,
      group: F,
      range: D,
      isWorkDay: a,
      isWorkHour: d,
      col: g,
      index: c,
      start: y,
      end: k,
      zonedStart: h,
      zonedEnd: m,
      navDay: u,
      itemsPerSlot: p,
      className: E
    } = this.$props, S = this.bv.selectedSlots.some((w) => b(w.cSlot, this.cSlot));
    let f;
    const v = x(B, {
      className: E,
      slotRender: this.$props.slotRender,
      isAllDay: this.isAllDay,
      expandable: this.expandable,
      editable: this.editable,
      items: n,
      row: I,
      group: F,
      range: D,
      isWorkDay: a,
      isWorkHour: d,
      col: g,
      index: c,
      start: y,
      end: k,
      zonedStart: h,
      zonedEnd: m,
      selected: S,
      navDay: u,
      itemsPerSlot: p,
      tabIndex: this.currentTabIndex,
      formItem: this.compFormItem,
      onFocus: this.handleFocus,
      onDoubleclick: this.handleDoubleClick,
      onKeydown: this.handleKeyDown,
      onShowmoreitems: this.handleShowMoreItemsClick
    }, H(t) ? t : {
      default: () => [t]
    });
    return f = j.call(this, {
      h: O,
      template: this.$props.slotRender,
      defaultRendering: v,
      defaultSlots: t,
      additionalProps: {
        ...this.cSlot,
        isAllDay: this.cSlot.isAllDay,
        expandable: this.expandable,
        editable: this.editable,
        items: n,
        row: this.cSlot.row,
        group: this.cSlot.group,
        range: this.cSlot.range,
        isWorkDay: a,
        isWorkHour: d,
        col: this.cSlot.col,
        index: c,
        start: this.cSlot.start,
        end: this.cSlot.end,
        zonedStart: h,
        zonedEnd: m,
        selected: S,
        navDay: u,
        itemsPerSlot: p,
        tabIndex: this.currentTabIndex
      },
      additionalListeners: {
        focus: this.handleFocus,
        doubleclick: this.handleDoubleClick,
        keydown: this.handleKeyDown,
        showmoreitems: this.handleShowMoreItemsClick
      }
    }), f;
  },
  methods: {
    handleShowMoreItemsClick(t) {
      this.$emit("showmoreitems", t);
    },
    createDataItemFromSlot() {
      const t = {};
      if (l(t, this.ks.fields.start, new Date(this.cSlot.start.getTime())), l(t, this.ks.fields.end, new Date(this.cSlot.end.getTime())), l(t, this.ks.fields.isAllDay, this.cSlot.isAllDay), this.cSlot.group.resources.length)
        for (let e = 0; e < this.cSlot.group.resources.length; e++) {
          const s = this.cSlot.group.resources[e];
          if ($(this.cSlot.group.resources)) {
            const o = _(this.cSlot.group.resources[e], s.valueField);
            l(t, s.field, s.multiple ? [o] : o);
          } else
            l(t, s.field, s.multiple ? [] : void 0);
        }
      return t;
    },
    handleFocus(t) {
      this.computedEditable.select && this.dispatchSelectedSlots({
        type: K.select,
        slot: this
      }, t.event), this.$emit("focus", t);
    },
    handleDoubleClick(t) {
      if (this.computedEditable.add) {
        const e = this.createDataItemFromSlot();
        this.setFormItem(e, t);
      }
      this.$emit("doubleclick", t);
    },
    handleKeyDown(t) {
      let e, s, o;
      switch (t.event.keyCode) {
        case i.left:
          if (!this.bv.slots)
            return;
          t.event.preventDefault(), this.dispatchFocusedSlots({
            type: r.left,
            slot: this
          }, t.event);
          break;
        case i.right:
          if (!this.bv.slots)
            return;
          t.event.preventDefault(), this.dispatchFocusedSlots({
            type: r.right,
            slot: this
          }, t.event);
          break;
        case i.up:
          if (!this.bv.slots)
            return;
          t.event.preventDefault(), this.dispatchFocusedSlots({
            type: r.up,
            slot: this
          }, t.event);
          break;
        case i.down:
          if (!this.bv.slots)
            return;
          t.event.preventDefault(), this.dispatchFocusedSlots({
            type: r.down,
            slot: this
          }, t.event);
          break;
        case i.enter:
          if (!this.bv.slots || !this.computedEditable.add)
            return;
          o = this.createDataItemFromSlot(), this.setFormItem(o);
          break;
        case i.tab:
          s = z(t.target), e = s ? R(s, this.bv.items, !1) : W(this.bv.items, this.ignoreIsAllDay)[0], this.dispatchFocusedItems({
            type: P.current,
            item: e
          }, t.event), this.dispatchSelectedItems({
            type: L.select,
            item: e
          }, t);
          break;
      }
      e && t.event.preventDefault();
    },
    handleEditFormSubmit(t) {
      this.$emit("dataaction", {
        type: N.create,
        series: !1,
        dataItem: t.value
      }, t), this.setFormItem(null, t.event);
    },
    handleEditFormCancel(t) {
      this.setFormItem(null, t.event);
    },
    handleEditFormClose(t) {
      this.setFormItem(null, t);
    },
    handleFormItemChange(t, e) {
      this.setFormItem && this.setFormItem(t, e);
    },
    setFormItem(t, e) {
      this.currentFormItem = t, this.$emit("formitemchange", e);
    }
  }
});
export {
  et as SchedulerEditSlot
};
