/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as o, createVNode as s } from "vue";
import { getDefaultSlots as i } from "@progress/kendo-vue-common";
import { formatEventTime as n, COLLECTION_ACTION as l } from "../utils/main.mjs";
import { provideIntlService as r } from "@progress/kendo-vue-intl";
import { ShowMoreItemsButton as a } from "../components/ShowMoreItemsButton.mjs";
import { SchedulerForm as h } from "../components/SchedulerForm.mjs";
const u = {
  skeleton: "dd"
}, $ = /* @__PURE__ */ o({
  name: "KendoSchedulerSlot",
  inheritAttrs: !1,
  emits: {
    focus: null,
    blur: null,
    click: null,
    showmoreitems: null,
    mouseover: null,
    mouseout: null,
    mouseenter: null,
    mouseleave: null,
    doubleclick: null,
    keydown: null,
    keypress: null,
    keyup: null,
    cancel: null,
    close: null,
    formsubmit: null
  },
  props: {
    refTo: [Function, Object],
    items: Array,
    row: Number,
    group: Object,
    range: Object,
    className: String,
    isWorkDay: {
      type: Boolean,
      default: !0
    },
    isWorkHour: {
      type: Boolean,
      default: !0
    },
    selected: Boolean,
    tabIndex: {
      type: Number,
      default: void 0
    },
    col: Number,
    index: Number,
    start: Date,
    end: Date,
    zonedStart: Object,
    zonedEnd: Object,
    isAllDay: Boolean,
    navDay: Boolean,
    editable: [Object, Boolean],
    itemsPerSlot: Number,
    formItem: Object,
    slotStyle: Object,
    viewSlot: Object
  },
  computed: {
    cSlot() {
      const e = this.ksSlots.cSlots;
      return e ? e[this.index] ? e[this.index] : e.length ? e[0] : {} : {};
    },
    currentTabIndex() {
      return this.$props.tabIndex !== void 0 ? this.$props.tabIndex === null ? void 0 : this.$props.tabIndex : this.$props.selected ? 0 : -1;
    },
    slotClass() {
      return {
        "k-scheduler-cell k-slot-cell": !0,
        "k-nonwork-hour": !this.$props.isWorkHour || !this.$props.isWorkDay,
        "k-selected": this.$props.selected,
        [this.$props.className]: this.$props.className
      };
    },
    slotLabel() {
      return `${n(this.intl, this.$props.zonedStart, this.$props.zonedEnd, this.$props.isAllDay || !1)}`;
    }
  },
  inject: {
    kendoIntlService: {
      default: null
    },
    setSlots: {
      default: null
    },
    slotClick: {
      default: null
    },
    slotDoubleClick: {
      default: null
    },
    ksEditFormSubmit: {
      default: null
    },
    ksEditFormCancel: {
      default: null
    },
    ksEditFormClose: {
      default: null
    },
    ksSlots: {
      default: {}
    }
  },
  data() {
    return {
      hasMounted: !1
    };
  },
  mounted() {
    this.hasMounted = !0, this.setSlots({
      type: l.add,
      item: this
    });
  },
  unmounted() {
    this.setSlots({
      type: l.remove,
      item: this
    });
  },
  render() {
    this.intl = r(this);
    const e = i(this), t = Object.assign({
      userSelect: "none"
    }, this.$props.slotStyle, this.$attrs.style);
    return s("div", {
      id: this.$props.id,
      style: t,
      class: this.slotClass,
      tabindex: this.currentTabIndex,
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      onClick: this.handleClick,
      onMouseenter: this.handleMouseEnter,
      onMouseleave: this.handleMouseLeave,
      onMouseover: this.handleMouseOver,
      onMouseout: this.handleMouseOut,
      onDblclick: this.handleDoubleClick,
      onKeydown: this.handleKeyDown,
      onKeypress: this.handleKeyPress,
      onKeyup: this.handleKeyUp,
      "data-slot": !0,
      "data-slot-allday": this.cSlot.isAllDay,
      "data-slot-start": this.cSlot.start.getTime(),
      "data-slot-end": this.cSlot.end.getTime(),
      "data-slot-group": this.cSlot.group.index,
      "data-slot-range": this.cSlot.range.index,
      "data-slot-index": this.cSlot.index
    }, [this.navDay && s("span", {
      class: "k-link k-nav-day"
    }, [this.intl.formatDate(new Date(this.cSlot.end.getTime() - (this.cSlot.end.getTime() - this.cSlot.start.getTime()) / 2), u)]), this.hasMounted && this.itemsPerSlot < this.cSlot.items.length && s(a, {
      onClick: this.handleShowMoreItemsClick
    }, null), e, this.formItem && s(h, {
      dataItem: this.formItem,
      onSubmit: this.handleFormSubmit,
      onClose: this.handleFormClose,
      onCancel: this.handleFormCancel
    }, null)]);
  },
  methods: {
    handleShowMoreItemsClick(e) {
      this.$emit("showmoreitems", e);
    },
    handleFocus(e) {
      this.$emit("focus", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleBlur(e) {
      this.$emit("blur", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleClick(e) {
      const t = {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      };
      this.$emit("click", t), this.slotClick(t);
    },
    handleMouseOver(e) {
      this.$emit("mouseover", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleMouseOut(e) {
      this.$emit("mouseout", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleMouseEnter(e) {
      this.$emit("mouseenter", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleMouseLeave(e) {
      this.$emit("mouseleave", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleDoubleClick(e) {
      const t = {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      };
      this.$emit("doubleclick", t), this.slotDoubleClick(t);
    },
    handleKeyDown(e) {
      this.$emit("keydown", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleKeyPress(e) {
      this.$emit("keypress", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleKeyUp(e) {
      this.$emit("keyup", {
        event: e,
        target: {
          props: {
            ...this.cSlot
          },
          element: this.$el
        }
      });
    },
    handleFormClose(e) {
      this.ksEditFormClose(e), this.$emit("close", e);
    },
    handleFormSubmit(e) {
      this.ksEditFormSubmit(e), this.$emit("formsubmit", e);
    },
    handleFormCancel(e) {
      this.ksEditFormCancel(e), this.$emit("cancel", e);
    }
  }
});
export {
  $ as SchedulerSlot
};
