/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as r, createVNode as o, isVNode as i } from "vue";
import { SchedulerViewTask as s } from "./SchedulerViewTask.mjs";
import { findMaster as n } from "../utils/main.mjs";
import { DATA_ACTION as c } from "../constants/main.mjs";
import { getDefaultSlots as a } from "@progress/kendo-vue-common";
import { useEditable as h } from "../hooks/useEditable.mjs";
function l(e) {
  return typeof e == "function" || Object.prototype.toString.call(e) === "[object Object]" && !i(e);
}
const v = /* @__PURE__ */ r({
  name: "KendoSchedulerEditTask",
  emits: ["dataaction", "showremovedialogchange", "showoccurrencedialogchange", "removeitemchange"],
  props: {
    viewTask: [String, Function, Object],
    removeDialog: [String, Function, Object],
    removeItem: [String, Function, Object],
    occurrenceDialog: [String, Function, Object],
    task: [String, Function, Object],
    showOccurrenceDialog: {
      type: Boolean,
      default: void 0
    },
    showRemoveDialog: {
      type: Boolean,
      default: void 0
    },
    series: {
      type: Boolean,
      default: void 0
    },
    refTo: [Function, Object],
    id: String,
    tabIndex: Number,
    editable: [Object, Boolean],
    head: Boolean,
    tail: Boolean,
    order: Number,
    zonedStart: Object,
    zonedEnd: Object,
    slots: Array,
    group: Object,
    range: Object,
    isException: Boolean,
    isRecurring: Boolean,
    isAllDay: Boolean,
    uid: [String, Number],
    start: Date,
    end: Date,
    originalStart: Date,
    startTimezone: String,
    endTimezone: String,
    title: String,
    description: String,
    occurrenceId: String,
    recurrenceExceptions: Array,
    recurrenceRule: String,
    recurrenceId: [String, Number],
    dataItem: Object
  },
  created() {
  },
  inject: {
    bv: {
      default: null
    },
    ks: {
      default: null
    }
  },
  provide() {
    return {
      et: this.et,
      removeTask: this.handleRemoveItemChange,
      removeDialog: this.handleRemoveDialogChange,
      occurrenceDialog: this.handleOccurrenceDialogChange,
      ksCancel: this.handleCancel,
      ksSeriesClick: this.handleSeriesClick,
      ksOccurrenceClick: this.handleOccurrenceClick,
      ksRemoveConfirm: this.handleRemoveConfirm
    };
  },
  data() {
    return {
      et: {
        removeItem: null,
        showRemoveDialog: !1,
        showOccurrenceDialog: !1
      },
      currentSeries: null,
      currentRemoveItem: null,
      currentShowRemoveDialog: null,
      currentShowOccurrenceDialog: null
    };
  },
  computed: {
    compSeries() {
      return this.series !== void 0 ? this.series : this.currentSeries;
    },
    compRemoveItem() {
      return this.removeItem !== void 0 ? this.removeItem : this.currentRemoveItem;
    },
    compShowRemoveDialog() {
      return this.showRemoveDialog !== void 0 ? this.showRemoveDialog : this.currentShowRemoveDialog;
    },
    compShowOccurrenceDialog() {
      return this.showOccurrenceDialog !== void 0 ? this.showOccurrenceDialog : this.currentShowOccurrenceDialog;
    },
    currentEditable() {
      return h(this.$props.editable);
    }
  },
  render() {
    const e = a(this);
    return o(s, {
      id: this.$props.id,
      tabIndex: this.$props.tabIndex,
      head: this.$props.head,
      tail: this.$props.tail,
      order: this.$props.order,
      zonedStart: this.$props.zonedStart,
      zonedEnd: this.$props.zonedEnd,
      slots: this.$props.slots,
      group: this.$props.group,
      range: this.$props.range,
      isException: this.$props.isException,
      isRecurring: this.$props.isRecurring,
      isAllDay: this.$props.isAllDay,
      uid: this.$props.uid,
      start: this.$props.start,
      end: this.$props.end,
      originalStart: this.$props.originalStart,
      startTimezone: this.$props.startTimezone,
      endTimezone: this.$props.endTimezone,
      title: this.$props.title,
      description: this.$props.description,
      occurrenceId: this.$props.occurrenceId,
      recurrenceExceptions: this.$props.recurrenceExceptions,
      recurrenceRule: this.$props.recurrenceRule,
      recurrenceId: this.$props.recurrenceId,
      dataItem: this.$props.dataItem,
      removeItem: this.compRemoveItem,
      task: this.$props.task,
      editable: this.$props.editable,
      showOccurrenceDialog: this.compShowOccurrenceDialog,
      showRemoveDialog: this.compShowRemoveDialog,
      onRemoveclick: this.handleRemoveClick
    }, l(e) ? e : {
      default: () => [e]
    });
  },
  methods: {
    setRemoveItem(e, t) {
      this.currentRemoveItem = e, this.$emit("removeitemchange", {
        item: e,
        event: t
      });
    },
    setShowRemoveDialog(e, t) {
      this.currentShowRemoveDialog = e, this.$emit("showremovedialogchange", {
        show: e,
        event: t
      });
    },
    setShowOccurrenceDialog(e, t) {
      this.currentShowOccurrenceDialog = e, this.$emit("showoccurrencedialogchange", {
        show: e,
        event: t
      });
    },
    handleRemoveClick(e) {
      this.currentEditable.remove && (this.setRemoveItem(this.$props.dataItem, e), this.$props.isRecurring ? this.setShowOccurrenceDialog(!0, e) : this.setShowRemoveDialog(!0, e));
    },
    handleCancel(e) {
      this.currentSeries = null, this.setRemoveItem(null, e), this.setShowRemoveDialog(!1, e), this.setShowOccurrenceDialog(!1, e);
    },
    handleRemoveConfirm(e) {
      this.compRemoveItem && this.$emit("dataaction", {
        type: c.remove,
        series: this.compSeries,
        dataItem: this.compRemoveItem
      }), this.setRemoveItem(null, e), this.setShowRemoveDialog(!1, e);
    },
    handleRemoveItemChange(e, t) {
      this.setRemoveItem && this.setRemoveItem(e, t);
    },
    handleRemoveDialogChange(e, t) {
      this.setShowRemoveDialog && this.setShowRemoveDialog(e, t);
    },
    handleOccurrenceDialogChange(e, t) {
      this.setShowOccurrenceDialog && this.setShowOccurrenceDialog(e, t);
    },
    handleOccurrenceClick(e) {
      this.compRemoveItem && (this.currentSeries = !1, this.setRemoveItem(this.$props.dataItem, e), this.setShowRemoveDialog(!0, e)), this.setShowOccurrenceDialog(!1, e);
    },
    handleSeriesClick(e) {
      if (this.compRemoveItem) {
        this.currentSeries = !0;
        const t = n(this.compRemoveItem, this.ks.fields, this.ks.dataItems);
        this.setRemoveItem(t, e), this.setShowRemoveDialog(!0, e);
      }
      this.setShowOccurrenceDialog(!1, e);
    }
  }
});
export {
  v as SchedulerEditTask
};
