/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as a, createVNode as e } from "vue";
import { provideLocalizationService as d } from "@progress/kendo-vue-intl";
import { deleteTitle as c, messages as u } from "../messages/main.mjs";
import { getDefaultSlots as m, Icon as r } from "@progress/kendo-vue-common";
import { SchedulerOccurrenceDialog as h } from "../components/SchedulerOccurrenceDialog.mjs";
import { SchedulerRemoveDialog as k } from "../components/SchedulerRemoveDialog.mjs";
import { arrowRotateCwIcon as p, arrowsNoRepeatIcon as g, xIcon as f } from "@progress/kendo-svg-icons";
import { useEditable as C } from "../hooks/useEditable.mjs";
const j = /* @__PURE__ */ a({
  name: "KendoSchedulerTask",
  props: {
    refTo: [Function, Object],
    id: String,
    tabIndex: Number,
    head: Boolean,
    tail: Boolean,
    order: Number,
    zonedStart: Object,
    zonedEnd: Object,
    slots: Array,
    group: Object,
    range: Object,
    isException: Boolean,
    isRecurring: Boolean,
    isAllDay: Boolean,
    uid: [String, Number],
    start: Date,
    end: Date,
    originalStart: Date,
    startTimezone: String,
    endTimezone: String,
    title: String,
    description: String,
    occurrenceId: String,
    recurrenceExceptions: Array,
    recurrenceRule: String,
    recurrenceId: [String, Number],
    dataItem: Object,
    removeItem: Object,
    editable: [Object, Boolean],
    showOccurrenceDialog: {
      type: Boolean,
      default: void 0
    },
    showRemoveDialog: {
      type: Boolean,
      default: void 0
    },
    onRemoveclick: Function
  },
  inject: {
    kendoLocalizationService: {
      default: null
    },
    taskClick: {
      default: null
    },
    taskDoubleClick: {
      default: null
    },
    ksCancel: {
      default: null
    },
    ksSeriesClick: {
      default: null
    },
    ksOccurrenceClick: {
      default: null
    },
    ksRemoveConfirm: {
      default: null
    }
  },
  created() {
    this.task = null;
  },
  render() {
    const t = m(this), o = C(this.$props.editable), s = d(this).toLanguageString(c, u[c]), i = this.$props.group.resources.find((n) => !!(n.colorField && n[n.colorField] !== void 0)), l = i && i.colorField && i[i.colorField];
    return e("div", {
      id: this.$props.id,
      class: "k-task",
      tabindex: this.$props.tabIndex || void 0,
      onClick: this.handleClick,
      onDblclick: this.handleDoubleClick
    }, [l && e("span", {
      class: "k-scheduler-mark",
      style: {
        color: l,
        backgroundColor: l
      }
    }, null), this.$props.isRecurring && e(r, {
      name: "arrow-rotate-cw",
      icon: p
    }, null), this.$props.isException && e(r, {
      name: "arrows-no-repeat",
      icon: g
    }, null), this.$props.title, t, o.remove && e("a", {
      class: "k-link k-event-delete",
      title: s,
      "aria-label": s,
      onClick: this.handleRemoveClick
    }, [e(r, {
      name: "x",
      icon: f
    }, null)]), this.showOccurrenceDialog && e(h, {
      dataItem: this.removeItem,
      isRemove: this.removeItem !== null,
      onClose: this.ksCancel,
      onOccurrenceclose: this.ksOccurrenceClick,
      onSeriesclose: this.ksSeriesClick
    }, null), this.showRemoveDialog && e(k, {
      dataItem: this.removeItem,
      onClose: this.ksCancel,
      onCancel: this.ksCancel,
      onConfirm: this.ksRemoveConfirm
    }, null)]);
  },
  methods: {
    handleRemoveClick(t) {
      this.$emit("removeclick", {
        event: t,
        target: this.task
      });
    },
    handleClick(t) {
      const o = {
        event: t,
        target: {
          props: {
            ...this.$props
          },
          element: this.$el
        }
      };
      this.$emit("click", o), this.taskClick(o);
    },
    handleDoubleClick(t) {
      const o = {
        event: t,
        target: {
          props: {
            ...this.$props
          },
          element: this.$el
        }
      };
      this.$emit("doubleclick", o), this.taskDoubleClick(o);
    }
  }
});
export {
  j as SchedulerTask
};
