/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as y, createVNode as t } from "vue";
import { BaseView as A } from "../../components/BaseView.mjs";
import { VerticalResourceIterator as c } from "../common/VerticalResourceIterator.mjs";
import { DAYS_IN_WEEK_COUNT as a } from "../../constants/main.mjs";
import { MS_PER_DAY as u, ZonedDate as i, firstDayInWeek as b, getDate as D, addDays as w } from "@progress/kendo-date-math";
import { provideIntlService as h, provideLocalizationService as E } from "@progress/kendo-vue-intl";
import { toRanges as $ } from "../../services/rangeService.mjs";
import { toOccurrences as v } from "../../services/occurrenceService.mjs";
import { toItems as R } from "../../services/itemsService.mjs";
import { mapItemsToSlots as z, mapSlotsToItems as I, toUTCDateTime as f } from "../../utils/main.mjs";
import { AgendaViewHead as V } from "./AgendaViewHead.mjs";
import { AgendaViewBody as _ } from "./AgendaViewBody.mjs";
import { SchedulerEditTask as N } from "../../tasks/SchedulerEditTask.mjs";
import { SchedulerEditSlot as C } from "../../slots/SchedulerEditSlot.mjs";
import { toSlots as x } from "../../services/slotsService.mjs";
import { useCellSync as s } from "../../hooks/useCellSync.mjs";
const ee = /* @__PURE__ */ y({
  name: "KendoAgendaView",
  props: {
    name: {
      type: String,
      default: "agenda"
    },
    // title: (localization: LocalizationService): string =>
    // localization.toLanguageString(agendaViewTitle, messages[agendaViewTitle]),
    dateRange: {
      type: [Function, Object],
      default: function() {
        return j;
      }
    },
    selectedDateFormat: {
      type: String,
      default: "{0:D} - {1:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d} - {1:d}"
    },
    slotDuration: {
      type: Number,
      default: 60 * 24
    },
    slotDivisions: {
      type: Number,
      default: 1
    },
    step: {
      type: Number,
      default: a
    },
    numberOfDays: {
      type: Number,
      default: a
    },
    task: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    }
  },
  inject: {
    ks: {
      default: null
    },
    kendoLocalizationService: {
      default: null
    },
    kendoIntlService: {
      default: null
    }
  },
  created() {
    this.intl = h(this);
  },
  mounted() {
    s({
      element: this.$el,
      selector: ".k-scheduler-datecolumn",
      explicitDepth: !1
    }), setTimeout(() => s({
      element: this.$el,
      selector: ".k-scheduler-timecolumn",
      explicitDepth: !1
    }));
  },
  updated() {
    s({
      element: this.$el,
      selector: ".k-scheduler-datecolumn",
      explicitDepth: !1
    }), setTimeout(() => s({
      element: this.$el,
      selector: ".k-scheduler-timecolumn",
      explicitDepth: !1
    }));
  },
  computed: {
    ranges() {
      return $(this.ks.dateRange, {
        step: u,
        timezone: this.ks.timezone
      });
    },
    agendaSlots() {
      return x(this.ks.dateRange, {
        step: u
      }, {
        groups: this.ks.groups,
        ranges: this.ranges
      });
    },
    occurrences() {
      return v(this.ks.dataItems, {
        dateRange: this.ks.dateRange,
        fields: this.ks.fields,
        timezone: this.ks.timezone
      });
    },
    items() {
      const e = R(this.occurrences, {
        timezone: this.ks.timezone
      }, {
        groups: this.ks.groups,
        ranges: this.ranges
      });
      return z(e, this.agendaSlots, !0), I(e, this.agendaSlots, !0), e;
    }
  },
  render() {
    this.$props.editTask || N, this.$props.editSlot || C, h(this), E(this);
    const e = this.agendaSlots;
    return t(A, {
      id: this.$props.id,
      class: "k-scheduler-agendaview",
      viewProps: {
        ...this.$props
      },
      baseSlots: this.items,
      ranges: this.ranges,
      isAgendaView: !0
    }, {
      default: () => [t("div", {
        class: "k-scheduler-head"
      }, [t(c, {
        resources: this.ks.props.resources,
        group: this.ks.props.group
      }, {
        default: () => [t(V, null, null)]
      })]), t(c, {
        resources: this.ks.props.resources,
        group: this.ks.props.group,
        nested: !0
      }, {
        default: () => [t(_, {
          items: this.items,
          agendaSlots: e,
          task: this.$props.task,
          editable: this.$props.editable,
          onDataaction: this.handleDataAction
        }, null)]
      })]
    });
  },
  methods: {
    handleDataAction(e) {
      this.$emit("dataaction", e);
    }
  }
}), g = (e) => D(e), O = (e, o) => D(w(e, o || 1)), j = ({
  intl: e,
  date: o,
  numberOfDays: n = 1,
  timezone: r
}) => {
  const l = i.fromLocalDate(o, r), d = g(n === a ? b(l, e.firstDay()) : l), k = O(d, n), m = i.fromUTCDate(f(d), r), p = i.fromUTCDate(f(k), r), S = new Date(m.getTime()), T = new Date(p.getTime());
  return {
    start: S,
    end: T,
    zonedStart: m,
    zonedEnd: p
  };
};
export {
  ee as AgendaView
};
