/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as k, createVNode as t } from "vue";
import { SchedulerEditSlot as S } from "../../slots/SchedulerEditSlot.mjs";
import { provideIntlService as f, provideLocalizationService as m } from "@progress/kendo-vue-intl";
import { SchedulerEditTask as v } from "../../tasks/SchedulerEditTask.mjs";
import { allDay as i, messages as d, noEvents as c } from "../../messages/main.mjs";
import { Icon as u } from "@progress/kendo-vue-common";
import { caretAltRightIcon as h, caretAltLeftIcon as p } from "@progress/kendo-svg-icons";
const R = /* @__PURE__ */ k({
  name: "KendoAgendaViewBody",
  emits: ["dataaction"],
  props: {
    items: Array,
    rangeIndex: Number,
    itemsPerSlot: Number,
    agendaSlots: Array,
    task: [String, Function, Object],
    editable: [Object, Boolean],
    onDataaction: Function
  },
  inject: {
    ri: {
      default: null
    },
    ks: {
      default: null
    },
    kendoIntlService: {
      default: null
    },
    kendoLocalizationService: {
      default: null
    },
    setSlots: {
      default: null
    }
  },
  provide() {
    return {
      ksSlots: this.ksSlots
    };
  },
  data() {
    return {
      hasMounted: !1,
      ksSlots: {
        cSlots: this.agendaSlots.filter((r) => r.group.index === (this.ri.groupIndex || 0))
      }
    };
  },
  watch: {
    currentCellSlots(r) {
      this.ksSlots.cSlots = r;
    }
  },
  computed: {
    currentCellSlots() {
      return this.agendaSlots.filter((r) => r.group.index === (this.ri.groupIndex || 0));
    }
  },
  mounted() {
    this.hasMounted = !0;
  },
  render() {
    this.intl = f(this);
    const r = this.$props.editSlot || S, a = this.$props.editTask || v, n = m(this);
    return t("div", {
      class: "k-scheduler-body"
    }, [this.currentCellSlots.map(function(l, s, g) {
      return t("div", {
        class: "k-scheduler-row  k-scheduler-content",
        key: `${this.ri.groupIndex}:${s}`
      }, [t(r, {
        index: s,
        editable: this.$props.editable,
        row: g.length * (this.ri.groupIndex || 0) + s,
        col: 0,
        viewSlot: this.$props.viewSlot,
        onDataaction: this.handleDataAction,
        className: "k-scheduler-datecolumn k-group-cell"
      }, {
        default: () => [t("div", null, [t("strong", {
          class: "k-scheduler-agendaday"
        }, [this.intl.formatDate(l.zonedStart, "dd")]), t("em", {
          class: "k-scheduler-agendaweek"
        }, [this.intl.formatDate(l.zonedStart, "EEEE")]), t("span", {
          class: "k-scheduler-agendadate"
        }, [this.intl.formatDate(l.zonedStart, "y")])])]
      }), t("div", {
        class: "k-scheduler-cell k-group-content"
      }, [this.hasMounted && l.items.length ? l.items.map(function(e, o) {
        return t("div", {
          class: "k-scheduler-row",
          key: o
        }, [t("div", {
          class: "k-scheduler-cell k-scheduler-timecolumn"
        }, [t("div", null, [e.tail && t(u, {
          name: this.ks.isRtl ? "caret-alt-right" : "caret-alt-left",
          icon: this.ks.isRtl ? h : p
        }, null), e.isAllDay ? n.toLanguageString(i, d[i]) : z(this.intl, e), e.head && t(u, {
          name: this.ks.isRtl ? "caret-alt-left" : "caret-alt-right",
          icon: this.ks.isRtl ? p : h
        }, null)])]), t("div", {
          class: "k-scheduler-cell"
        }, [t(a, {
          key: `${s}:${o}`,
          uid: e.uid,
          start: e.start,
          end: e.end,
          originalStart: e.originalStart,
          startTimezone: e.startTimezone,
          endTimezone: e.endTimezone,
          isAllDay: e.isAllDay,
          title: e.title,
          description: e.description,
          occurrenceId: e.occurrenceId,
          recurrenceExceptions: e.recurrenceExceptions,
          recurrenceRule: e.recurrenceRule,
          recurrenceId: e.recurrenceId,
          dataItem: e.dataItem,
          itemRef: e.itemRef,
          head: e.head,
          tail: e.tail,
          order: e.order,
          zonedStart: e.zonedStart,
          zonedEnd: e.zonedEnd,
          slots: e.slots,
          group: e.group,
          range: e.range,
          isException: e.isException,
          isRecurring: e.isRecurring,
          onDataaction: this.handleDataAction,
          task: this.$props.task,
          viewTask: this.$props.viewTask,
          editable: this.$props.editable
        }, null)])]);
      }, this) : t("div", {
        class: "k-scheduler-cell k-heading-cell k-group-cell"
      }, [n.toLanguageString(c, d[c])])])]);
    }, this)]);
  },
  methods: {
    handleDataAction(r) {
      this.$emit("dataaction", r);
    }
  }
}), z = (r, a) => {
  let n = "{0:t}-{1:t}";
  return a.head ? n = "{0:t}" : a.tail && (n = "{1:t}"), r.format(n, a.zonedStart, a.zonedEnd);
};
export {
  R as AgendaViewBody
};
