/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as a, createVNode as s } from "vue";
import { MultiDayView as e } from "./MultiDayView.mjs";
import { dayViewTitle as r, messages as n } from "../../messages/main.mjs";
import { provideLocalizationService as p } from "@progress/kendo-vue-intl";
import { Day as o } from "@progress/kendo-date-math";
const h = /* @__PURE__ */ a({
  name: "KendoDayView",
  emits: {
    dataaction: null
  },
  props: {
    name: {
      type: String,
      default: "day"
    },
    title: String,
    dateRange: {
      type: [Function, Object],
      default: function() {
        return e.props.dateRange.default();
      }
    },
    showWorkHours: {
      type: Boolean,
      default: !0
    },
    step: {
      type: Number,
      default: 1
    },
    numberOfDays: {
      type: Number,
      default: 1
    },
    slotDuration: {
      type: Number,
      default: 60
    },
    slotDivisions: {
      type: Number,
      default: 2
    },
    selectedDateFormat: {
      type: String,
      default: "{0:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d}"
    },
    currentTimeMarker: {
      type: Boolean,
      default: !0
    },
    startTime: {
      type: String,
      default: "00:00"
    },
    endTime: {
      type: String,
      default: "23:59"
    },
    workDayStart: {
      type: String,
      default: "08:00"
    },
    workDayEnd: {
      type: String,
      default: "17:00"
    },
    workWeekStart: {
      type: Number,
      default: o.Monday
    },
    workWeekEnd: {
      type: Number,
      default: o.Friday
    },
    defaultShowWorkHours: {
      type: Boolean,
      default: !0
    },
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    },
    format: String
  },
  inject: {
    kendoLocalizationService: {
      default: null
    }
  },
  render() {
    const i = p(this).toLanguageString(r, n[r]);
    return s(e, {
      name: this.$props.name,
      dateRange: this.$props.dateRange,
      step: this.$props.step,
      numberOfDays: this.$props.numberOfDays,
      slotDuration: this.$props.slotDuration,
      slotDivisions: this.$props.slotDivisions,
      selectedDateFormat: this.$props.selectedDateFormat,
      selectedShortDateFormat: this.$props.selectedShortDateFormat,
      showWorkHours: this.$props.showWorkHours,
      title: i,
      currentTimeMarker: this.$props.currentTimeMarker,
      startTime: this.$props.startTime,
      endTime: this.$props.endTime,
      workDayStart: this.$props.workDayStart,
      workDayEnd: this.$props.workDayEnd,
      workWeekStart: this.$props.workWeekStart,
      workWeekEnd: this.$props.workWeekEnd,
      defaultShowWorkHours: this.$props.defaultShowWorkHours,
      timeHeaderCell: this.$props.timeHeaderCell,
      dateHeaderCell: this.$props.dateHeaderCell,
      slotRender: this.$props.slotRender,
      viewSlot: this.$props.viewSlot,
      resizeHint: this.$props.resizeHint,
      item: this.$props.item,
      viewItem: this.$props.viewItem,
      editable: this.$props.editable,
      onDataaction: this.handleDataAction
    }, null);
  },
  methods: {
    handleDataAction(t) {
      this.$emit("dataaction", t);
    }
  }
});
export {
  h as DayView
};
