/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as l, createVNode as s } from "vue";
import { classNames as d } from "@progress/kendo-vue-common";
import { GRID_OFFSET as u } from "../../constants/main.mjs";
import { SchedulerEditSlot as c } from "../../slots/SchedulerEditSlot.mjs";
import { isInTimeRange as m } from "../../utils/main.mjs";
const k = /* @__PURE__ */ l({
  name: "KendoDayViewMiddleRow",
  props: {
    editable: [Object, Boolean],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    timeRanges: Array,
    timeSlots: Array,
    slotDivisions: {
      type: Number,
      default: 2
    },
    rootIndex: {
      type: Number
    },
    root: Object,
    numberOfDays: Number,
    workDayStart: Date,
    workDayEnd: Date,
    workWeekStart: Number,
    workWeekEnd: Number,
    onDataaction: Function
  },
  inject: {
    ri: {
      default: null
    },
    setSlots: {
      default: null
    }
  },
  provide() {
    return {
      ksSlots: this.ksSlots
    };
  },
  data() {
    const e = this.timeSlots, t = this.ri.groupIndex, o = this.root;
    return {
      ksSlots: {
        cSlots: this.calculateRanges(e, t, this.timeRanges, o)
      }
    };
  },
  watch: {
    currentCellSlots(e) {
      this.ksSlots.cSlots = e;
    }
  },
  computed: {
    currentCellSlots() {
      const e = this.timeSlots, t = this.ri.groupIndex, o = this.root;
      return this.calculateRanges(e, t, this.timeRanges, o);
    }
  },
  render() {
    const e = this.$props.editSlot || c, t = this, o = t.numberOfDays + t.workWeekStart;
    return s("div", {
      class: d("k-scheduler-row", {
        "k-middle-row": (this.rootIndex + 1) % this.slotDivisions !== 0
      })
    }, [this.currentCellSlots.map(function(r, i) {
      return s(e, {
        index: i,
        onDataaction: this.handleDataAction,
        slotRender: this.$props.slotRender,
        viewSlot: this.$props.viewSlot,
        form: this.$props.form,
        row: this.rootIndex + u,
        col: this.timeRanges.length * (this.ri.groupIndex || 0) + r.range.index,
        isWorkHour: m(r.zonedStart, t.workDayStart, t.workDayEnd),
        isWorkDay: 0 <= r.zonedStart.getDay() + (t.numberOfDays - o) && (r.zonedStart.getDay() + (t.numberOfDays - o)) % t.numberOfDays <= t.workWeekEnd + (t.numberOfDays - o),
        editable: t.$props.editable
      }, null);
    }, t)]);
  },
  methods: {
    handleDataAction(e) {
      this.$emit("dataaction", e);
    },
    calculateRanges(e, t, o, r) {
      return o.map(function(i, a) {
        return e.filter((n) => n.index === r.index && n.range.index === a && n.group.index === t);
      }).flat();
    }
  }
});
export {
  k as DayViewMiddleRow
};
