/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as V, createVNode as r } from "vue";
import { Day as S, MS_PER_DAY as w, ZonedDate as k, getDate as F, addDays as j } from "@progress/kendo-date-math";
import { BaseView as N } from "../../components/BaseView.mjs";
import { HorizontalResourceIterator as I } from "../common/HorizontalResourceIterator.mjs";
import { DayViewGroupRowContent as R } from "./DayViewGroupRowContent.mjs";
import { VerticalResourceIterator as $ } from "../common/VerticalResourceIterator.mjs";
import { DayViewAllDayRowContent as z } from "./DayViewAllDayRowContent.mjs";
import { DayViewRowContent as B } from "./DayViewRowContent.mjs";
import { DayViewMiddleRow as U } from "./DayViewMiddleRow.mjs";
import { DayViewVerticalRow as _ } from "./DayViewVerticalRow.mjs";
import { DayViewHead as v } from "./DayViewHead.mjs";
import { DayViewAllDaySlots as P } from "./DayViewAllDaySlots.mjs";
import { isInTimeRange as m, mapItemsToSlots as E, mapSlotsToItems as b, intersects as L, last as G, first as K, toUTCDateTime as T } from "../../utils/main.mjs";
import { provideIntlService as c } from "@progress/kendo-vue-intl";
import { MS_PER_MINUTE as X } from "../../constants/main.mjs";
import { SchedulerDrag as C } from "../common/SchedulerDrag.mjs";
import { SchedulerEditSlot as Y } from "../../slots/SchedulerEditSlot.mjs";
import { SchedulerEditItem as Z } from "../../items/SchedulerEditItem.mjs";
import { CurrentTimeMarker as q } from "../../components/CurrentTimeMarker.mjs";
import { CurrentTimeMarkerArrow as J } from "../../components/CurrentTimeMarkerArrow.mjs";
import { SchedulerResize as A } from "../common/SchedulerResize.mjs";
import { toRanges as x } from "../../services/rangeService.mjs";
import { toSlots as O } from "../../services/slotsService.mjs";
import { toOccurrences as Q } from "../../services/occurrenceService.mjs";
import { toItems as W } from "../../services/itemsService.mjs";
const H = 0, ve = /* @__PURE__ */ V({
  name: "KendoMultiDayView",
  props: {
    name: {
      type: String,
      default: "multi-day"
    },
    title: {
      type: String,
      default: "Multi Day"
    },
    currentTimeMarker: {
      type: Boolean,
      default: !0
    },
    dateRange: {
      type: [Function, Object],
      default: function() {
        return ee;
      }
    },
    numberOfDays: {
      type: Number,
      default: 1
    },
    startTime: {
      type: String,
      default: "00:00"
    },
    endTime: {
      type: String,
      default: "23:59"
    },
    workDayStart: {
      type: String,
      default: "08:00"
    },
    workDayEnd: {
      type: String,
      default: "17:00"
    },
    workWeekStart: {
      type: Number,
      default: S.Monday
    },
    workWeekEnd: {
      type: Number,
      default: S.Friday
    },
    step: {
      type: Number,
      default: 1
    },
    slotDivisions: {
      type: Number,
      default: 2
    },
    slotDuration: {
      type: Number,
      default: 60
    },
    showWorkHours: {
      type: Boolean,
      default: !0
    },
    selectedDateFormat: {
      type: String,
      default: "{0:D} - {1:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d} - {1:d}"
    },
    dragItem: {
      type: Object,
      default: function() {
      }
    },
    resizeItem: {
      type: Object,
      default: function() {
      }
    },
    format: {
      type: String,
      default: "t"
    },
    defaultShowWorkHours: {
      type: Boolean,
      default: !0
    },
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    },
    onDataaction: Function
  },
  inject: {
    kendoIntlService: {
      default: null
    },
    ks: {
      default: null
    }
  },
  computed: {
    viewStart() {
      this.intl = c(this);
      const t = this.intl.parseDate(this.$props.workDayStart), s = this.intl.parseDate(this.$props.startTime);
      return (this.ks.showWorkHours !== void 0 ? this.ks.showWorkHours : this.showWorkHours) ? t : s;
    },
    viewEnd() {
      this.intl = c(this);
      const t = this.intl.parseDate(this.$props.workDayEnd), s = this.intl.parseDate(this.$props.endTime);
      return (this.ks.showWorkHours !== void 0 ? this.ks.showWorkHours : this.showWorkHours) ? t : s;
    },
    dayRanges() {
      return x(this.ks.dateRange, {
        step: w * this.numberOfDays,
        timezone: this.ks.timezone
      }).map((t) => ({
        ...t,
        isAllDay: !0
      }));
    },
    timeRanges() {
      return x(this.ks.dateRange, {
        step: w,
        timezone: this.ks.timezone
      }).map((t) => ({
        ...t,
        isAllDay: !1
      }));
    },
    daySlots() {
      return O(this.ks.dateRange, {
        step: w
      }, {
        groups: this.ks.groups,
        ranges: this.dayRanges
      });
    },
    timeSlots() {
      const t = this;
      return O(this.ks.dateRange, {
        step: this.slotDuration * X / this.slotDivisions
      }, {
        groups: this.ks.groups,
        ranges: this.timeRanges
      }).filter((s) => t.viewEnd.getTime() === t.viewStart.getTime() || m(s.zonedStart, t.viewStart, t.viewEnd));
    },
    occurrences() {
      return Q(this.ks.dataItems, {
        dateRange: this.ks.dateRange,
        fields: this.ks.fields,
        timezone: this.ks.timezone
      });
    },
    dayOccurrences() {
      return this.occurrences.filter((t) => t.isAllDay);
    },
    timeOccurrences() {
      return this.occurrences.filter((t) => !t.isAllDay);
    },
    dayItems() {
      const t = W(this.dayOccurrences, {
        timezone: this.ks.timezone
      }, {
        groups: this.ks.groups,
        ranges: this.dayRanges
      });
      return E(t, this.daySlots, !1), b(t, this.daySlots, !1), t;
    },
    timeItems() {
      const t = W(this.timeOccurrences, {
        timezone: this.ks.timezone
      }, {
        groups: this.ks.groups,
        ranges: this.timeRanges
      }).filter((s) => this.viewStart.getTime() === this.viewEnd.getTime() || m(s.zonedStart, this.viewStart, this.viewEnd) || m(s.zonedEnd, this.viewStart, this.viewEnd) || m(new Date(s.zonedEnd.getTime() - (s.zonedEnd.getTime() - s.zonedStart.getTime()) / 2), this.viewStart, this.viewEnd));
      return E(t, this.timeSlots, !1), b(t, this.timeSlots, !1), t;
    },
    compDragItem() {
      return this.dragItem !== void 0 ? this.dragItem : this.currentDragItem;
    },
    compResizeItem() {
      return this.resizeItem !== void 0 ? this.resizeItem : this.currentResizeItem;
    }
  },
  data() {
    return {
      hasMounted: !1,
      currentDragItem: void 0,
      currentResizeItem: void 0
    };
  },
  mounted() {
    this.hasMounted = !0;
  },
  created() {
    this.intl = c(this);
  },
  beforeUpdate() {
    this.intl = c(this);
  },
  render() {
    this.intl = c(this);
    const t = this.$props.editItem || Z;
    this.$props.editSlot || Y, this.$props.showWorkHours;
    const s = this.$props.numberOfDays, i = this.$props.slotDivisions;
    this.$props.slotDuration;
    const a = this.$props.workWeekStart, n = this.$props.workWeekEnd, h = this.intl.parseDate(this.$props.workDayStart), d = this.intl.parseDate(this.$props.workDayEnd), l = this.dayItems, g = this.timeItems, u = this.daySlots, p = this.timeSlots, M = this.ks.view.name === "workweek" || this.ks.view.name === "week", f = function(e) {
      return this.compDragItem && this.$props.editable.drag && (Array.isArray(this.compDragItem) ? this.compDragItem.map(function(o, y) {
        return r(C, {
          key: y,
          dataItem: o,
          vertical: e,
          item: this.$props.dataItem
        }, null);
      }, this) : r(C, {
        dataItem: this.compDragItem,
        vertical: e,
        item: this.$props.dataItem
      }, null));
    }, D = function(e) {
      return this.compResizeItem && this.editable.resize && (Array.isArray(this.compResizeItem) ? this.compResizeItem.map(function(o, y) {
        return r(A, {
          key: y,
          format: this.$props.format,
          dataItem: o,
          viewItem: this.$props.viewItem,
          item: this.$props.item,
          vertical: e
        }, null);
      }, this) : r(A, {
        format: this.$props.format,
        dataItem: this.compResizeItem,
        viewItem: this.$props.viewItem,
        item: this.$props.item,
        vertical: e
      }, null));
    };
    return r(N, {
      id: this.$props.id,
      viewProps: {
        ...this.$props
      },
      class: M ? "k-scheduler-weekview" : "k-scheduler-dayview",
      ranges: [...this.dayRanges, ...this.timeRanges],
      baseSlots: [...u, ...p]
    }, {
      default: () => [r("div", {
        class: "k-scheduler-head"
      }, [this.ks.orientation === "horizontal" ? [r(I, {
        nested: !0,
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        rowContent: R,
        childRowContent: R
      }, {
        default: () => [r(v, {
          timeRanges: this.timeRanges,
          dateHeaderCell: this.$props.dateHeaderCell
        }, null)]
      }), r(I, {
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        rowContent: z,
        childRowContent: z
      }, {
        default: () => [r(P, {
          editable: this.$props.editable,
          dayRanges: this.dayRanges,
          daySlots: u,
          slotRender: this.$props.slotRender,
          viewSlot: this.$props.viewSlot,
          numberOfDays: s,
          workWeekStart: a,
          workWeekEnd: n,
          onDataaction: this.handleDataAction
        }, null)]
      }), this.hasMounted && l.map(function(e) {
        return r(t, {
          key: e.isRecurring ? `${e.uid}:${e.group.index}:${e.range.index}:${e.originalStart}` : `${e.uid}:${e.group.index}:${e.range.index}`,
          uid: e.uid,
          start: e.start,
          end: e.end,
          originalStart: e.originalStart,
          startTimezone: e.startTimezone,
          endTimezone: e.endTimezone,
          isAllDay: e.isAllDay,
          title: e.title,
          description: e.description,
          occurrenceId: e.occurrenceId,
          recurrenceExceptions: e.recurrenceExceptions,
          recurrenceRule: e.recurrenceRule,
          recurrenceId: e.recurrenceId,
          dataItem: e.dataItem,
          itemRef: e.itemRef,
          head: e.head,
          tail: e.tail,
          order: e.order,
          zonedStart: e.zonedStart,
          zonedEnd: e.zonedEnd,
          slots: e.slots,
          group: e.group,
          range: e.range,
          isException: e.isException,
          isRecurring: e.isRecurring,
          form: this.$props.form,
          onDataaction: this.handleDataAction,
          onDragitemchange: this.handleDragItemChange,
          onResizeitemchange: this.handleResizeItemChange,
          item: this.$props.item,
          viewItem: this.$props.viewItem,
          editable: this.$props.editable,
          vertical: !1
        }, null);
      }, this), this.compDragItem && this.compDragItem.isAllDay && f.call(this, !1), this.compResizeItem && this.compResizeItem.isAllDay && D.call(this, !1)] : r($, {
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        emptyCell: !0,
        editable: this.$props.editable
      }, {
        default: () => [r(v, {
          timeRanges: this.timeRanges,
          dateHeaderCell: this.$props.dateHeaderCell
        }, null)]
      })]), r("div", {
        class: "k-scheduler-body"
      }, [this.ks.orientation === "horizontal" ? [p.filter((e) => e.group.index === H && e.range.index === H).map(function(e, o) {
        return r(I, {
          key: e.index,
          nested: !1,
          group: this.ks.props.group,
          resources: this.ks.props.resources,
          rowContent: B,
          rowContentProps: {
            timeHeaderCell: this.$props.timeHeaderCell,
            isMaster: o % i === 0,
            isLast: (o + 1) % i === 0,
            contentSlot: e
          }
        }, {
          default: () => [r(U, {
            slotRender: this.$props.slotRender,
            viewSlot: this.$props.viewSlot,
            timeRanges: this.timeRanges,
            timeSlots: p,
            slotDivisions: i,
            rootIndex: o,
            root: e,
            numberOfDays: s,
            workDayStart: h,
            workDayEnd: d,
            workWeekStart: a,
            workWeekEnd: n,
            onDataaction: this.handleDataAction,
            editable: this.$props.editable
          }, null)]
        });
      }, this), this.$props.currentTimeMarker && L(K(this.timeRanges).start, G(this.timeRanges).end, /* @__PURE__ */ new Date(), /* @__PURE__ */ new Date(), !0) && [r(J, null, null), r(q, null, null)]] : [r($, {
        nested: !0,
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        onDataaction: this.handleDataAction,
        more: {
          timeRanges: this.timeRanges,
          timeSlots: p,
          workDayStart: h,
          workDayEnd: d,
          numberOfDays: s,
          workWeekStart: a,
          workWeekEnd: n,
          slotRender: this.$props.slotRender,
          viewSlot: this.$props.viewSlot,
          editable: this.$props.editable,
          currentTimeMarker: this.$props.currentTimeMarker
        }
      }, {
        default: () => [r(_, {
          onDataaction: this.handleDataAction,
          daySlots: u,
          timeSlots: p,
          dayRanges: this.dayRanges,
          editable: this.$props.editable
        }, null)]
      }), this.hasMounted && l.map(function(e) {
        return r(t, {
          key: e.isRecurring ? `${e.uid}:${e.group.index} : ${e.range.index} : ${e.originalStart}` : `${e.uid}:${e.group.index} : ${e.range.index}`,
          uid: e.uid,
          start: e.start,
          end: e.end,
          originalStart: e.originalStart,
          startTimezone: e.startTimezone,
          endTimezone: e.endTimezone,
          isAllDay: e.isAllDay,
          title: e.title,
          description: e.description,
          occurrenceId: e.occurrenceId,
          recurrenceExceptions: e.recurrenceExceptions,
          recurrenceRule: e.recurrenceRule,
          recurrenceId: e.recurrenceId,
          dataItem: e.dataItem,
          itemRef: e.itemRef,
          head: e.head,
          tail: e.tail,
          order: e.order,
          zonedStart: e.zonedStart,
          zonedEnd: e.zonedEnd,
          slots: e.slots,
          group: e.group,
          range: e.range,
          isException: e.isException,
          isRecurring: e.isRecurring,
          onDataaction: this.handleDataAction,
          onDragitemchange: this.handleDragItemChange,
          onResizeitemchange: this.handleResizeItemChange,
          viewItem: this.$props.viewItem,
          item: this.$props.item,
          form: this.$props.form,
          editable: this.$props.editable,
          vertical: !1
        }, null);
      }, this), this.compDragItem && this.compDragItem.isAllDay && f.call(this, !0), this.compResizeItem && this.compResizeItem.isAllDay && D.call(this, !0)], this.hasMounted && g.map(function(e) {
        return r(t, {
          key: e.isRecurring ? `${e.uid}:${e.group.index}:${e.range.index}:${e.originalStart}` : `${e.uid}:${e.group.index}:${e.range.index}`,
          uid: e.uid,
          start: e.start,
          end: e.end,
          originalStart: e.originalStart,
          startTimezone: e.startTimezone,
          endTimezone: e.endTimezone,
          isAllDay: e.isAllDay,
          title: e.title,
          description: e.description,
          occurrenceId: e.occurrenceId,
          recurrenceExceptions: e.recurrenceExceptions,
          recurrenceRule: e.recurrenceRule,
          recurrenceId: e.recurrenceId,
          dataItem: e.dataItem,
          itemRef: e.itemRef,
          head: e.head,
          tail: e.tail,
          order: e.order,
          zonedStart: e.zonedStart,
          zonedEnd: e.zonedEnd,
          slots: e.slots,
          group: e.group,
          range: e.range,
          isException: e.isException,
          isRecurring: e.isRecurring,
          format: "t",
          onDataaction: this.handleDataAction,
          onDragitemchange: this.handleDragItemChange,
          onResizeitemchange: this.handleResizeItemChange,
          viewItem: this.$props.viewItem,
          item: this.$props.item,
          form: this.$props.form,
          editable: this.$props.editable,
          vertical: !0
        }, null);
      }, this), this.compDragItem && !this.compDragItem.isAllDay && f.call(this, !0), this.compResizeItem && !this.compResizeItem.isAllDay && D.call(this, !0)])]
    });
  },
  methods: {
    handleDataAction(t) {
      this.$emit("dataaction", t);
    },
    handleDragItemChange(t) {
      this.currentDragItem = t;
    },
    handleResizeItemChange(t) {
      this.currentResizeItem = t;
    }
  }
}), ee = ({
  date: t,
  numberOfDays: s = 1,
  timezone: i
}) => {
  const a = k.fromLocalDate(t, i), n = F(a), h = j(n, s), d = k.fromUTCDate(T(n), i), l = k.fromUTCDate(T(h), i), g = new Date(d.getTime()), u = new Date(l.getTime());
  return {
    start: g,
    end: u,
    zonedStart: d,
    zonedEnd: l
  };
};
export {
  ve as MultiDayView,
  ee as multiDayViewDateRange
};
