/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as k, createVNode as t } from "vue";
import { BaseView as b } from "../../components/BaseView.mjs";
import { MS_PER_DAY as m, firstDayInWeek as p, firstDayOfMonth as v, getDate as c, addDays as w, lastDayOfMonth as A, ZonedDate as h } from "@progress/kendo-date-math";
import { VerticalResourceIterator as g } from "../common/VerticalResourceIterator.mjs";
import { HorizontalResourceIterator as f } from "../common/HorizontalResourceIterator.mjs";
import { mapItemsToSlots as C, mapSlotsToItems as O, orderSort as T, toUTCDateTime as I } from "../../utils/main.mjs";
import { monthViewTitle as S, messages as E } from "../../messages/main.mjs";
import { SchedulerEditSlot as j } from "../../slots/SchedulerEditSlot.mjs";
import { provideIntlService as D, provideLocalizationService as x } from "@progress/kendo-vue-intl";
import { DAYS_IN_WEEK_COUNT as $ } from "../../constants/main.mjs";
import { toRanges as M } from "../../services/rangeService.mjs";
import { toSlots as F } from "../../services/slotsService.mjs";
import { toOccurrences as V } from "../../services/occurrenceService.mjs";
import { toItems as H } from "../../services/itemsService.mjs";
import { MonthViewHead as z } from "./MonthViewHead.mjs";
import { MonthViewBody as N } from "./MonthViewBody.mjs";
import { SchedulerEditItem as P } from "../../items/SchedulerEditItem.mjs";
import { SchedulerResize as y } from "../common/SchedulerResize.mjs";
import { SchedulerDrag as R } from "../common/SchedulerDrag.mjs";
const ae = /* @__PURE__ */ k({
  name: "KendoMonthView",
  props: {
    itemsPerSlot: {
      type: Number,
      default: 2
    },
    name: {
      type: String,
      default: "month"
    },
    dateRange: {
      type: [Function, Object],
      default: function() {
        return _;
      }
    },
    slotDuration: {
      type: Number,
      default: 24 * 60
    },
    slotDivisions: {
      type: Number,
      default: 1
    },
    numberOfDays: {
      type: Number,
      default: 31
    },
    dragItem: {
      type: Object,
      default: function() {
      }
    },
    resizeItem: {
      type: Object,
      default: function() {
      }
    },
    title: String,
    selectedDateFormat: {
      type: String,
      default: "{0:Y}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:Y}"
    },
    dateHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    }
  },
  inject: {
    ks: {
      default: {}
    },
    kendoLocalizationService: {
      default: null
    },
    kendoIntlService: {
      default: null
    }
  },
  created() {
    this.intl = D(this);
  },
  mounted() {
    this.hasMounted = !0;
  },
  data() {
    return {
      hasMounted: !1,
      currentDragItem: void 0,
      currentResizeItem: void 0
    };
  },
  computed: {
    ranges() {
      return M(this.ks.dateRange, {
        step: m * $,
        timezone: this.ks.timezone
      });
    },
    monthSlots() {
      return F(this.ks.dateRange, {
        step: m
      }, {
        groups: this.ks.groups,
        ranges: this.ranges
      });
    },
    occurrences() {
      return V(this.ks.dataItems, {
        dateRange: this.ks.dateRange,
        fields: this.ks.fields,
        timezone: this.ks.timezone
      });
    },
    items() {
      const r = H(this.occurrences, {
        timezone: this.ks.timezone
      }, {
        groups: this.ks.groups,
        ranges: this.ranges
      });
      return C(r, this.monthSlots, !0), O(r, this.monthSlots, !0), r;
    },
    compDragItem() {
      return this.dragItem !== void 0 ? this.dragItem : this.currentDragItem;
    },
    compResizeItem() {
      return this.resizeItem !== void 0 ? this.resizeItem : this.currentResizeItem;
    }
  },
  render() {
    this.localization = x(this), this.localization.toLanguageString(S, E[S]);
    const r = this.$props.editItem || P;
    this.$props.editSlot || j;
    const n = this.items, s = this.monthSlots, l = function(e) {
      return this.compDragItem && this.$props.editable.drag && (Array.isArray(this.compDragItem) ? this.compDragItem.map(function(o, u) {
        return t(R, {
          key: u,
          ignoreIsAllDay: !0,
          dataItem: o,
          vertical: e,
          item: this.$props.dataItem
        }, null);
      }, this) : t(R, {
        ignoreIsAllDay: !0,
        dataItem: this.compDragItem,
        vertical: e,
        item: this.$props.dataItem
      }, null));
    }, d = function(e) {
      return this.compResizeItem && this.editable.resize && (Array.isArray(this.compResizeItem) ? this.compResizeItem.map(function(o, u) {
        return t(y, {
          key: u,
          format: this.$props.format,
          ignoreIsAllDay: !0,
          dataItem: o,
          viewItem: this.$props.viewItem,
          item: this.$props.item,
          vertical: e
        }, null);
      }, this) : t(y, {
        format: this.$props.format,
        ignoreIsAllDay: !0,
        dataItem: this.compResizeItem,
        viewItem: this.$props.viewItem,
        item: this.$props.item,
        vertical: e
      }, null));
    };
    this.intl = D(this);
    const i = this.$props.itemsPerSlot, a = this.ks.orientation === "horizontal" ? this.ranges.map(function(e, o) {
      return t(f, {
        resources: this.ks.props.resources,
        group: this.ks.props.group
      }, {
        default: () => [t(N, {
          editable: this.$props.editable,
          slotRender: this.$props.slotRender,
          viewSlot: this.$props.viewSlot,
          monthSlots: s,
          rangeIndex: o,
          itemsPerSlot: i,
          onDataaction: this.handleDataAction
        }, null)]
      });
    }, this) : t(g, {
      nested: !0,
      resources: this.ks.props.resources,
      group: this.ks.props.group,
      onDataaction: this.handleDataAction,
      more: {
        slotRender: this.$props.slotRender,
        viewSlot: this.$props.viewSlot,
        monthSlots: s,
        ranges: this.ranges,
        itemsPerSlot: i,
        editable: this.$props.editable
      }
    }, null);
    return t(b, {
      viewProps: {
        ...this.$props
      },
      baseSlots: s,
      ranges: this.ranges,
      class: "k-scheduler-monthview"
    }, {
      default: () => [t("div", {
        class: "k-scheduler-head"
      }, [this.ks.orientation === "horizontal" ? t(f, {
        nested: !0,
        resources: this.ks.props.resources,
        group: this.ks.props.group
      }, {
        default: () => [t(z, {
          monthSlots: s,
          dateHeaderCell: this.$props.dateHeaderCell
        }, null)]
      }) : t(g, {
        resources: this.ks.props.resources,
        group: this.ks.props.group
      }, {
        default: () => [t(z, {
          monthSlots: s,
          dateHeaderCell: this.$props.dateHeaderCell
        }, null)]
      })]), t("div", {
        class: "k-scheduler-body"
      }, [a, this.hasMounted && n.filter((e) => e.order === null || e.order < i).sort(T).map(function(e) {
        return t(r, {
          item: this.$props.item,
          viewItem: this.$props.viewItem,
          form: this.$props.form,
          key: e.isRecurring ? `${e.uid}:${e.group.index}:${e.range.index}:${e.originalStart}` : `${e.uid}:${e.group.index}:${e.range.index}`,
          uid: e.uid,
          start: e.start,
          end: e.end,
          originalStart: e.originalStart,
          startTimezone: e.startTimezone,
          endTimezone: e.endTimezone,
          isAllDay: e.isAllDay,
          title: e.title,
          description: e.description,
          occurrenceId: e.occurrenceId,
          recurrenceExceptions: e.recurrenceExceptions,
          recurrenceRule: e.recurrenceRule,
          recurrenceId: e.recurrenceId,
          dataItem: e.dataItem,
          itemRef: e.itemRef,
          head: e.head,
          tail: e.tail,
          order: e.order,
          zonedStart: e.zonedStart,
          zonedEnd: e.zonedEnd,
          slots: e.slots,
          group: e.group,
          range: e.range,
          isException: e.isException,
          isRecurring: e.isRecurring,
          onDragitemchange: this.handleDragItemChange,
          onResizeitemchange: this.handleResizeItemChange,
          onDataaction: this.handleDataAction,
          itemStyle: {
            transform: "translateY(30px)"
          },
          vertical: !1,
          editable: this.$props.editable,
          ignoreIsAllDay: !0
        }, null);
      }, this), this.compDragItem && l.call(this, !1), this.compResizeItem && d.call(this, !1)])]
    });
  },
  methods: {
    handleDataAction(r) {
      this.$emit("dataaction", r);
    },
    handleDragItemChange(r) {
      this.currentDragItem = r;
    },
    handleResizeItemChange(r) {
      this.currentResizeItem = r;
    }
  }
}), _ = ({
  intl: r,
  date: n,
  timezone: s
}) => {
  const l = p(v(c(n)), r.firstDay()), d = w(p(A(c(n)), r.firstDay()), $), i = h.fromUTCDate(I(l), s), a = h.fromUTCDate(I(d), s), e = new Date(i.getTime()), o = new Date(a.getTime());
  return {
    start: e,
    end: o,
    zonedStart: i,
    zonedEnd: a
  };
};
export {
  ae as MonthView
};
