/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as l, createVNode as i } from "vue";
import { SchedulerEditSlot as d } from "../../slots/SchedulerEditSlot.mjs";
import { classNames as h } from "@progress/kendo-vue-common";
import { provideIntlService as u } from "@progress/kendo-vue-intl";
const S = /* @__PURE__ */ l({
  name: "KendoMonthViewBody",
  props: {
    editable: [Object, Boolean],
    groupIndex: Number,
    rangeIndex: Number,
    itemsPerSlot: Number,
    monthSlots: Array,
    ranges: Array,
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    onDataaction: Function
  },
  inject: {
    ri: {
      default: {}
    },
    ks: {
      default: null
    },
    setActiveDate: {
      default: null
    },
    setActiveViewName: {
      default: null
    },
    setSlots: {
      default: null
    },
    kendoIntlService: {
      default: null
    }
  },
  provide() {
    return {
      ksSlots: this.ksSlots
    };
  },
  data() {
    const e = this.groupIndex !== void 0 ? this.groupIndex : this.ri.groupIndex;
    return {
      ksSlots: {
        cSlots: this.monthSlots.filter((t) => t.group.index === e && t.range.index === this.rangeIndex)
      }
    };
  },
  watch: {
    currentCellSlots(e) {
      this.ksSlots.cSlots = e;
    }
  },
  computed: {
    currentCellSlots() {
      const e = this.groupIndex !== void 0 ? this.groupIndex : this.ri.groupIndex;
      return this.monthSlots.filter((t) => t.group.index === e && t.range.index === this.rangeIndex);
    }
  },
  render() {
    this.intl = u(this);
    const e = this.$props.editSlot || d, t = this, n = this.groupIndex !== void 0 ? this.groupIndex : this.ri.groupIndex;
    return i("div", {
      class: "k-scheduler-row",
      key: this.rangeIndex
    }, [this.currentCellSlots.map(function(o, r, s) {
      return i(e, {
        className: h({
          "k-other-month": this.isOtherMonth(o, this.ks.currentDate)
        }),
        slotRender: this.$props.slotRender,
        viewSlot: t.$props.viewSlot,
        form: t.$props.form,
        index: r,
        navDay: !0,
        itemsPerSlot: t.itemsPerSlot,
        expandable: {
          offsetTop: 30,
          offsetBottom: t.itemsPerSlot < o.items.length ? 15 : 0
        },
        onDataaction: t.handleDataAction,
        col: t.ks.orientation === "horizontal" ? s.length * (n || 0) + r : r,
        row: t.ks.orientation === "horizontal" ? t.rangeIndex : t.ranges.length * (n || 0) + t.rangeIndex,
        editable: t.$props.editable,
        onShowmoreitems: (a) => t.handleShowMoreItemsClick(a, o)
      }, null);
    }, this)]);
  },
  methods: {
    handleShowMoreItemsClick(e, t) {
      const n = this.ks.views.find((o) => o.name === "day");
      !this.setActiveViewName || !n || !n.name || !t || (this.setActiveViewName(n.name, e), this.setActiveDate(t.start, e));
    },
    handleDataAction(e) {
      this.$emit("dataaction", e);
    },
    isOtherMonth(e, t) {
      return e.start.getMonth() < t.getMonth() || e.start.getMonth() > t.getMonth();
    }
  }
});
export {
  S as MonthViewBody
};
