/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as T, createVNode as r, isVNode as b } from "vue";
import { BaseView as v } from "../../components/BaseView.mjs";
import { Day as D, MS_PER_DAY as E, MS_PER_MINUTE as x, ZonedDate as g, getDate as A, addDays as C } from "@progress/kendo-date-math";
import { HorizontalResourceIterator as y } from "../common/HorizontalResourceIterator.mjs";
import { TimelineViewRowContent as O } from "./TimelineViewRowContent.mjs";
import { TimelineViewAllEventsRowContent as M } from "./TimelineViewAllEventsRowContent.mjs";
import { VerticalResourceIterator as S } from "../common/VerticalResourceIterator.mjs";
import { isInTimeRange as h, mapItemsToSlots as j, mapSlotsToItems as F, orderSort as H, toUTCDateTime as w } from "../../utils/main.mjs";
import { toRanges as N } from "../../services/rangeService.mjs";
import { toSlots as V } from "../../services/slotsService.mjs";
import { toOccurrences as W } from "../../services/occurrenceService.mjs";
import { toItems as _ } from "../../services/itemsService.mjs";
import { TimelineViewBody as B } from "./TimelineViewBody.mjs";
import { BORDER_WIDTH as U } from "../../constants/main.mjs";
import { provideIntlService as f } from "@progress/kendo-vue-intl";
import { SchedulerEditItem as P } from "../../items/SchedulerEditItem.mjs";
import { SchedulerResize as I } from "../common/SchedulerResize.mjs";
import { SchedulerDrag as k } from "../common/SchedulerDrag.mjs";
import { DateHeaderCell as G } from "../../components/DateHeaderCell.mjs";
import { TimeHeaderCell as K } from "../../components/TimeHeaderCell.mjs";
import { useRowSync as z } from "../../hooks/useRowSync.mjs";
import { useCellSync as R } from "../../hooks/useCellSync.mjs";
function $(t) {
  return typeof t == "function" || Object.prototype.toString.call(t) === "[object Object]" && !b(t);
}
const L = "t", X = 0, ye = /* @__PURE__ */ T({
  name: "KendoMultiDayTimelineView",
  props: {
    name: {
      type: String,
      default: "multi-day-timeline"
    },
    title: {
      type: String,
      default: "Multi Day Timeline"
    },
    currentTimeMarker: {
      type: Boolean,
      default: !0
    },
    dragItem: {
      type: Object,
      default: function() {
      }
    },
    resizeItem: {
      type: Object,
      default: function() {
      }
    },
    showWorkHours: {
      type: Boolean,
      default: !0
    },
    dateRange: {
      type: [Function, Object],
      default: function() {
        return Y;
      }
    },
    selectedDateFormat: {
      type: String,
      default: "{0:D} - {1:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d} - {1:d}"
    },
    step: {
      type: Number,
      default: 1
    },
    numberOfDays: {
      type: Number,
      default: 1
    },
    startTime: {
      type: String,
      default: "00:00"
    },
    endTime: {
      type: String,
      default: "00:00"
    },
    workDayStart: {
      type: String,
      default: "8:00"
    },
    workDayEnd: {
      type: String,
      default: "17:00"
    },
    workWeekStart: {
      type: Number,
      default: D.Monday
    },
    workWeekEnd: {
      type: Number,
      default: D.Friday
    },
    slotDivisions: {
      type: Number,
      default: 2
    },
    slotDuration: {
      type: Number,
      default: 60
    },
    defaultShowWorkHours: {
      type: Boolean,
      default: !0
    },
    columnWidth: {
      type: Number,
      default: 100
    },
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    },
    onDataaction: Function
  },
  data() {
    return {
      hasMounted: !1,
      currentDragItem: void 0,
      currentResizeItem: void 0
    };
  },
  inject: {
    ks: {
      default: null
    },
    kendoIntlService: {
      default: null
    }
  },
  computed: {
    viewStart() {
      this.intl = f(this);
      const t = this.intl.parseDate(this.$props.workDayStart), i = this.intl.parseDate(this.$props.startTime);
      return this.showWorkHours ? t : i;
    },
    viewEnd() {
      this.intl = f(this);
      const t = this.intl.parseDate(this.$props.workDayEnd), i = this.intl.parseDate(this.$props.endTime);
      return this.showWorkHours ? t : i;
    },
    ranges() {
      return N(this.ks.dateRange, {
        step: E,
        timezone: this.ks.timezone
      });
    },
    timelineSlots() {
      return V(this.ks.dateRange, {
        step: this.slotDuration / this.slotDivisions * x
      }, {
        groups: this.ks.groups,
        ranges: this.ranges
      }).filter((i) => h(i.zonedStart, this.viewStart, this.viewEnd) || this.viewStart.getTime() === this.viewEnd.getTime());
    },
    occurrences() {
      return W(this.ks.dataItems, {
        dateRange: this.ks.dateRange,
        fields: this.ks.fields,
        timezone: this.ks.timezone
      });
    },
    items() {
      const t = _(this.occurrences, {
        timezone: this.ks.timezone
      }, {
        groups: this.ks.groups,
        ranges: this.ranges
      }).filter((i) => this.viewStart.getTime() === this.viewEnd.getTime() || h(i.zonedStart, this.viewStart, this.viewEnd) || h(i.zonedEnd, this.viewStart, this.viewEnd) || h(new Date(i.zonedEnd.getTime() - (i.zonedEnd.getTime() - i.zonedStart.getTime()) / 2), this.viewStart, this.viewEnd));
      return j(t, this.timelineSlots, !0), F(t, this.timelineSlots, !0), t;
    },
    compDragItem() {
      return this.dragItem !== void 0 ? this.dragItem : this.currentDragItem;
    },
    compResizeItem() {
      return this.resizeItem !== void 0 ? this.resizeItem : this.currentResizeItem;
    }
  },
  mounted() {
    this.timeRef = null, this.bodyRef = null, this.hasMounted = !0, R({
      element: this.$el,
      selector: ".k-resource-cell",
      attribute: "data-depth-index",
      explicitDepth: !0
    }), z({
      element: this.$el,
      selector: ".k-resource-row",
      horizontalAttribute: "data-depth-index",
      verticalAttribute: "data-resource-index",
      applyTo: ".k-resource-cell"
    });
  },
  updated() {
    R({
      element: this.$el,
      selector: ".k-resource-cell",
      attribute: "data-depth-index",
      explicitDepth: !0
    }), z({
      element: this.$el,
      selector: ".k-resource-row",
      horizontalAttribute: "data-depth-index",
      verticalAttribute: "data-resource-index",
      applyTo: ".k-resource-cell"
    });
  },
  render() {
    const t = f(this), i = this.$props.slotDuration, l = t.parseDate(this.$props.workDayStart), u = t.parseDate(this.$props.workDayEnd), p = [...this.items], o = [...this.timelineSlots], d = (this.ks.orientation === "horizontal" ? o.length : o.length / this.ks.groups.length) * (this.$props.columnWidth + U), c = function(e) {
      return this.compDragItem && this.$props.editable.drag && (Array.isArray(this.compDragItem) ? this.compDragItem.map(function(a, s) {
        return r(k, {
          key: s,
          ignoreIsAllDay: !0,
          dataItem: a,
          vertical: e,
          item: this.$props.dataItem
        }, null);
      }, this) : r(k, {
        ignoreIsAllDay: !0,
        dataItem: this.compDragItem,
        vertical: e,
        item: this.$props.dataItem
      }, null));
    }, m = function(e) {
      return this.compResizeItem && this.editable.resize && (Array.isArray(this.compResizeItem) ? this.compResizeItem.map(function(a, s) {
        return r(I, {
          key: s,
          format: this.$props.format,
          ignoreIsAllDay: !0,
          dataItem: a,
          viewItem: this.$props.viewItem,
          item: this.$props.item,
          vertical: e
        }, null);
      }, this) : r(I, {
        format: this.$props.format,
        ignoreIsAllDay: !0,
        dataItem: this.compResizeItem,
        viewItem: this.$props.viewItem,
        item: this.$props.item,
        vertical: e
      }, null));
    }, n = [r("div", {
      class: "k-scheduler-row"
    }, [this.ranges.map(function(e, a) {
      return r(G, {
        as: this.$props.dateHeaderCell,
        key: a,
        date: e.zonedStart,
        start: e.start,
        end: e.end,
        format: "m"
      }, null);
    }, this)]), r("div", {
      class: "k-scheduler-row",
      ref: "timeRef"
    }, [this.ranges.map(function(e, a) {
      return o.filter((s) => s.group.index === X && s.range.index === a).map(function(s) {
        return s.zonedStart.getMinutes() % i === 0 ? r(K, {
          key: s.index,
          as: this.$props.timeHeaderCell,
          format: L,
          date: s.zonedStart,
          start: s.zonedStart,
          end: s.zonedEnd
        }, null) : null;
      }, this);
    }, this)])];
    return r(v, {
      id: this.$props.id,
      class: "k-scheduler-timeline-view",
      viewProps: {
        ...this.$props
      },
      baseSlots: o,
      ranges: this.ranges
    }, {
      default: () => [r("div", {
        class: "k-scheduler-head",
        style: {
          width: d + "px"
        }
      }, [this.ks.orientation === "horizontal" ? r(y, {
        nested: !0,
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        rowContent: O
      }, $(n) ? n : {
        default: () => [n]
      }) : r(S, {
        wrapGroup: !0,
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        editable: this.$props.editable
      }, $(n) ? n : {
        default: () => [n]
      })]), r("div", {
        class: "k-scheduler-body",
        style: {
          width: d + "px"
        },
        ref: "bodyRef"
      }, [this.ks.orientation === "horizontal" ? r(y, {
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        rowContent: M
      }, {
        default: () => [r(B, {
          editable: this.$props.editable,
          slotRender: this.$props.slotRender,
          viewSlot: this.$props.viewSlot,
          ranges: this.ranges,
          workDayStart: l,
          workDayEnd: u,
          timelineSlots: o,
          onDataaction: this.handleDataAction
        }, null)]
      }) : r(S, {
        nested: !0,
        wrapGroup: !0,
        group: this.ks.props.group,
        resources: this.ks.props.resources,
        onDataaction: this.handleDataAction,
        more: {
          ranges: this.ranges,
          workDayStart: l,
          workDayEnd: u,
          timelineSlots: o,
          slotRender: this.$props.slotRender,
          viewSlot: this.$props.viewSlot,
          editable: this.$props.editable,
          currentTimeMarker: this.$props.currentTimeMarker
        }
      }, null), this.hasMounted && p.sort(H).map(function(e) {
        return r(P, {
          key: e.isRecurring ? `${e.uid}:${e.group.index}:${e.range.index}:${e.originalStart}` : `${e.uid}:${e.group.index}:${e.range.index}`,
          uid: e.uid,
          start: e.start,
          end: e.end,
          originalStart: e.originalStart,
          startTimezone: e.startTimezone,
          endTimezone: e.endTimezone,
          isAllDay: e.isAllDay,
          title: e.title,
          description: e.description,
          occurrenceId: e.occurrenceId,
          recurrenceExceptions: e.recurrenceExceptions,
          recurrenceRule: e.recurrenceRule,
          recurrenceId: e.recurrenceId,
          dataItem: e.dataItem,
          itemRef: e.itemRef,
          head: e.head,
          tail: e.tail,
          order: e.order,
          zonedStart: e.zonedStart,
          zonedEnd: e.zonedEnd,
          slots: e.slots,
          group: e.group,
          range: e.range,
          isException: e.isException,
          isRecurring: e.isRecurring,
          format: "t",
          form: this.$props.form,
          onDragitemchange: this.handleDragItemChange,
          onResizeitemchange: this.handleResizeItemChange,
          onDataaction: this.handleDataAction,
          item: this.$props.item,
          viewItem: this.$props.viewItem,
          editable: this.$props.editable,
          ignoreIsAllDay: !0,
          vertical: !1
        }, null);
      }, this), this.compDragItem && c.call(this, !1), this.compResizeItem && m.call(this, !1)])]
    });
  },
  methods: {
    handleDataAction(t) {
      this.$emit("dataaction", t);
    },
    handleDragItemChange(t) {
      this.currentDragItem = t;
    },
    handleResizeItemChange(t) {
      this.currentResizeItem = t;
    }
  }
}), Y = ({
  date: t,
  numberOfDays: i = 1,
  timezone: l
}) => {
  const u = g.fromLocalDate(t, l), p = A(u), o = C(p, i), d = g.fromUTCDate(w(p), l), c = g.fromUTCDate(w(o), l), m = new Date(d.getTime()), n = new Date(c.getTime());
  return {
    start: m,
    end: n,
    zonedStart: d,
    zonedEnd: c
  };
};
export {
  ye as MultiDayTimelineView
};
