/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as i, createVNode as o } from "vue";
import { MultiDayTimelineView as e } from "./MultiDayTimelineView.mjs";
import { Day as t } from "@progress/kendo-date-math";
const p = /* @__PURE__ */ i({
  name: "KendoTimelineView",
  emits: {
    dataaction: null
  },
  props: {
    name: {
      type: String,
      default: "timeline"
    },
    title: {
      type: String,
      default: "Multi Day Timeline"
    },
    currentTimeMarker: {
      type: Boolean,
      default: !0
    },
    dateRange: {
      type: [Function, Object],
      default: function() {
        return e.props.dateRange.default();
      }
    },
    showWorkHours: {
      type: Boolean,
      default: !0
    },
    selectedDateFormat: {
      type: String,
      default: "{0:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d}"
    },
    step: {
      type: Number,
      default: 1
    },
    numberOfDays: {
      type: Number,
      default: 1
    },
    startTime: {
      type: String,
      default: "00:00"
    },
    endTime: {
      type: String,
      default: "00:00"
    },
    workDayStart: {
      type: String,
      default: "8:00"
    },
    workDayEnd: {
      type: String,
      default: "17:00"
    },
    workWeekStart: {
      type: Number,
      default: t.Monday
    },
    workWeekEnd: {
      type: Number,
      default: t.Friday
    },
    slotDivisions: {
      type: Number,
      default: 2
    },
    slotDuration: {
      type: Number,
      default: 60
    },
    defaultShowWorkHours: {
      type: Boolean,
      default: !0
    },
    columnWidth: {
      type: Number,
      default: 100
    },
    dragItem: {
      type: Object,
      default: function() {
      }
    },
    resizeItem: {
      type: Object,
      default: function() {
      }
    },
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: [Object, Boolean]
  },
  render() {
    return o(e, {
      name: this.$props.name,
      dragItem: this.$props.dragItem,
      resizeItem: this.$props.resizeItem,
      dateRange: this.$props.dateRange,
      step: this.$props.step,
      numberOfDays: this.$props.numberOfDays,
      slotDuration: this.$props.slotDuration,
      slotDivisions: this.$props.slotDivisions,
      selectedDateFormat: this.$props.selectedDateFormat,
      selectedShortDateFormat: this.$props.selectedShortDateFormat,
      showWorkHours: this.$props.showWorkHours,
      columnWidth: this.$props.columnWidth,
      title: this.$props.title,
      currentTimeMarker: this.$props.currentTimeMarker,
      startTime: this.$props.startTime,
      endTime: this.$props.endTime,
      workDayStart: this.$props.workDayStart,
      workDayEnd: this.$props.workDayEnd,
      workWeekStart: this.$props.workWeekStart,
      workWeekEnd: this.$props.workWeekEnd,
      timeHeaderCell: this.$props.timeHeaderCell,
      dateHeaderCell: this.$props.dateHeaderCell,
      slotRender: this.$props.slotRender,
      viewSlot: this.$props.viewSlot,
      resizeHint: this.$props.resizeHint,
      item: this.$props.item,
      viewItem: this.$props.viewItem,
      editable: this.$props.editable,
      onDataaction: this.handleDataAction
    }, null);
  },
  methods: {
    handleDataAction(r) {
      this.$emit("dataaction", r);
    }
  }
});
export {
  p as TimelineView
};
