/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as u, createVNode as l } from "vue";
import { SchedulerEditSlot as d } from "../../slots/SchedulerEditSlot.mjs";
import { isInTimeRange as c, intersects as p, last as h, first as g } from "../../utils/main.mjs";
import { CurrentTimeMarker as m } from "../../components/CurrentTimeMarker.mjs";
const w = /* @__PURE__ */ u({
  name: "KendoTimelineViewBody",
  props: {
    currentTimeMarker: {
      type: Boolean,
      default: !0
    },
    groupIndex: Number,
    timelineSlots: Array,
    ranges: Array,
    workDayStart: Date,
    workDayEnd: Date,
    editable: [Object, Boolean],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    onDataaction: Function
  },
  inject: {
    ri: {
      default: null
    },
    ks: {
      default: null
    },
    setSlots: {
      default: null
    }
  },
  provide() {
    return {
      ksSlots: this.ksSlots
    };
  },
  data() {
    const t = this.timelineSlots, e = this.groupIndex !== void 0 ? this.groupIndex : this.ri.groupIndex;
    return {
      ksSlots: {
        cSlots: this.calculateRanges(t, e, this.ranges)
      }
    };
  },
  watch: {
    currentCellSlots(t) {
      this.ksSlots.cSlots = t;
    }
  },
  computed: {
    currentCellSlots() {
      const t = this.timelineSlots, e = this.groupIndex !== void 0 ? this.groupIndex : this.ri.groupIndex;
      return this.calculateRanges(t, e, this.ranges);
    }
  },
  render() {
    const t = this, e = this.ks.orientation, r = this.ranges, o = this.groupIndex !== void 0 ? this.groupIndex : this.ri.groupIndex, i = this.$props.editable;
    return l("div", {
      class: "k-scheduler-row"
    }, [this.currentCellSlots.map(function(n, s, a) {
      return l(d, {
        slotRender: t.$props.slotRender,
        viewSlot: t.$props.viewSlot,
        index: s,
        form: t.$props.form,
        onDataaction: t.handleDataAction,
        isWorkHour: c(n.zonedStart, t.workDayStart, t.workDayEnd),
        col: e === "horizontal" ? n.range.index * a.length + s + a.length * r.length * (o || 0) : n.range.index * a.length + s,
        row: e === "horizontal" ? 0 : o || 0,
        expandable: !0,
        editable: i
      }, null);
    }, this), this.$props.currentTimeMarker && p(g(r).start, h(r).end, /* @__PURE__ */ new Date(), /* @__PURE__ */ new Date(), !0) && l(m, {
      groupIndex: o,
      vertical: !0
    }, null)]);
  },
  methods: {
    handleDataAction(t) {
      this.$emit("dataaction", t);
    },
    calculateRanges(t, e, r) {
      return r.map((o, i) => t.filter((n) => n.group.index === e && n.range.index === i)).flat();
    }
  }
});
export {
  w as TimelineViewBody
};
