/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as h, createVNode as S } from "vue";
import { MultiDayView as k } from "../day/MultiDayView.mjs";
import { DAYS_IN_WEEK_COUNT as i } from "../../constants/main.mjs";
import { Day as l, ZonedDate as o, firstDayInWeek as w, getDate as m, addDays as y } from "@progress/kendo-date-math";
import { weekViewTitle as p, messages as g } from "../../messages/main.mjs";
import { toUTCDateTime as d } from "../../utils/main.mjs";
import { provideLocalizationService as $ } from "@progress/kendo-vue-intl";
const N = /* @__PURE__ */ h({
  name: "KendoWeekView",
  emits: {
    dataaction: null
  },
  props: {
    name: {
      type: String,
      default: "week"
    },
    slotDuration: {
      type: Number,
      default: 60
    },
    slotDivisions: {
      type: Number,
      default: 2
    },
    numberOfDays: {
      type: Number,
      default: i
    },
    dateRange: {
      type: [Function, Object],
      default: function() {
        return W;
      }
    },
    title: String,
    selectedDateFormat: {
      type: String,
      default: "{0:D} - {1:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d} - {1:d}"
    },
    showWorkHours: {
      type: Boolean,
      default: !0
    },
    currentTimeMarker: {
      type: Boolean,
      default: !0
    },
    startTime: {
      type: String,
      default: "00:00"
    },
    endTime: {
      type: String,
      default: "23:59"
    },
    workDayStart: {
      type: String,
      default: "08:00"
    },
    workDayEnd: {
      type: String,
      default: "17:00"
    },
    workWeekStart: {
      type: Number,
      default: l.Monday
    },
    workWeekEnd: {
      type: Number,
      default: l.Friday
    },
    defaultShowWorkHours: {
      type: Boolean,
      default: !0
    },
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    },
    format: String
  },
  inject: {
    kendoLocalizationService: {
      default: null
    }
  },
  render() {
    const e = $(this).toLanguageString(p, g[p]);
    return S(k, {
      name: this.$props.name,
      dateRange: this.$props.dateRange,
      numberOfDays: this.$props.numberOfDays,
      slotDuration: this.$props.slotDuration,
      slotDivisions: this.$props.slotDivisions,
      selectedDateFormat: this.$props.selectedDateFormat,
      selectedShortDateFormat: this.$props.selectedShortDateFormat,
      showWorkHours: this.$props.showWorkHours,
      title: e,
      step: i,
      currentTimeMarker: this.$props.currentTimeMarker,
      startTime: this.$props.startTime,
      endTime: this.$props.endTime,
      workDayStart: this.$props.workDayStart,
      workDayEnd: this.$props.workDayEnd,
      workWeekStart: this.$props.workWeekStart,
      workWeekEnd: this.$props.workWeekEnd,
      defaultShowWorkHours: this.$props.defaultShowWorkHours,
      dateHeaderCell: this.$props.dateHeaderCell,
      timeHeaderCell: this.$props.timeHeaderCell,
      slotRender: this.$props.slotRender,
      viewSlot: this.$props.viewSlot,
      resizeHint: this.$props.resizeHint,
      item: this.$props.item,
      viewItem: this.$props.viewItem,
      editable: this.$props.editable,
      onDataaction: this.handleDataAction
    }, null);
  },
  methods: {
    handleDataAction(t) {
      this.$emit("dataaction", t);
    }
  }
}), T = (t) => m(t), b = (t, e) => m(y(t, e)), W = ({
  intl: t,
  date: e,
  timezone: r
}) => {
  const u = o.fromLocalDate(e, r), a = T(w(u, t.firstDay())), c = b(a, i), n = o.fromUTCDate(d(a), r), s = o.fromUTCDate(d(c), r), D = new Date(n.getTime()), f = new Date(s.getTime());
  return {
    start: D,
    end: f,
    zonedStart: n,
    zonedEnd: s
  };
};
export {
  N as WeekView
};
