/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as g, createVNode as h } from "vue";
import { Day as n, MS_PER_DAY as y, ZonedDate as s, getDate as b, addDays as W } from "@progress/kendo-date-math";
import { DAYS_IN_WEEK_COUNT as u } from "../../constants/main.mjs";
import { MultiDayView as F } from "../day/MultiDayView.mjs";
import { workWeekViewTitle as p, messages as $ } from "../../messages/main.mjs";
import { toUTCDateTime as m } from "../../utils/main.mjs";
import { provideLocalizationService as O } from "@progress/kendo-vue-intl";
const V = /* @__PURE__ */ g({
  name: "KendoWorkWeekView",
  emits: {
    dataaction: null
  },
  props: {
    name: {
      type: String,
      default: "work-week"
    },
    slotDuration: {
      type: Number,
      default: 60
    },
    slotDivisions: {
      type: Number,
      default: 2
    },
    numberOfDays: {
      type: Number,
      default: 7
    },
    dateRange: {
      type: [Function, Object],
      default: function() {
        return H;
      }
    },
    title: String,
    workWeekStart: {
      type: Number,
      default: n.Monday
    },
    workWeekEnd: {
      type: Number,
      default: n.Friday
    },
    selectedDateFormat: {
      type: String,
      default: "{0:D} - {1:D}"
    },
    selectedShortDateFormat: {
      type: String,
      default: "{0:d} - {1:d}"
    },
    showWorkHours: {
      type: Boolean,
      default: !0
    },
    dateHeaderCell: [String, Function, Object],
    timeHeaderCell: [String, Function, Object],
    slotRender: [String, Function, Object],
    viewSlot: [String, Function, Object],
    resizeHint: [String, Function, Object],
    item: [String, Function, Object],
    viewItem: [String, Function, Object],
    editable: {
      type: [Boolean, Object],
      default: !1
    }
  },
  inject: {
    kendoLocalizationService: {
      default: null
    },
    ks: {
      default: null
    }
  },
  render() {
    const a = O(this).toLanguageString(p, $[p]), e = this.ks.dateRange, t = Math.round((e.end.getTime() - e.start.getTime()) / y);
    return h(F, {
      name: this.$props.name,
      dateRange: this.$props.dateRange,
      numberOfDays: t,
      slotDuration: this.$props.slotDuration,
      slotDivisions: this.$props.slotDivisions,
      selectedDateFormat: this.$props.selectedDateFormat,
      selectedShortDateFormat: this.$props.selectedShortDateFormat,
      showWorkHours: this.$props.showWorkHours,
      title: a,
      step: u,
      slotRender: this.$props.slotRender,
      viewSlot: this.$props.viewSlot,
      resizeHint: this.$props.resizeHint,
      item: this.$props.item,
      viewItem: this.$props.viewItem,
      editable: this.$props.editable,
      dateHeaderCell: this.$props.dateHeaderCell,
      timeHeaderCell: this.$props.timeHeaderCell,
      onDataaction: this.handleDataAction
    }, null);
  },
  methods: {
    handleDataAction(o) {
      this.$emit("dataaction", o);
    }
  }
}), v = (o, a = n.Sunday) => {
  let e = o.clone();
  for (; e.getDay() !== a; )
    e = e.addDays(-1);
  return e;
}, H = ({
  intl: o,
  date: a,
  timezone: e,
  ...t
}) => {
  const D = s.fromLocalDate(a, e), i = t.workWeekStart !== void 0 ? t.workWeekStart : n.Monday, r = t.workWeekEnd !== void 0 ? t.workWeekEnd : n.Friday, f = r < i ? u + r - i + 1 : r - i + 1, d = b(v(D, i)), k = W(d, f), l = s.fromUTCDate(m(d), e), c = s.fromUTCDate(m(k), e), w = new Date(l.getTime()), S = new Date(c.getTime());
  return {
    start: w,
    end: S,
    zonedStart: l,
    zonedEnd: c
  };
};
export {
  V as WorkWeekView
};
